%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Rhe                                                           %
%    Nikolai Sthler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Rhe,                       %
%    Nikolai Sthler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//*************************************************************************
// 1: Define objects that are passed to Dynare's macro processor
//*************************************************************************

// Define the index of the country/countries used in the model.
@#define country    = ["a"]

//Specify the number of sectors included in the model.
@#define sector     = 10

//*************************************************************************
// 2: Declare the "usual suspects". Given the above specifications, Dynare's macroprocessor pre-processes the variables, parameters and shocks.
//
// 2.1: "Vars_params_10S_1C.m" specify model variables, exogenous shocks and parameters.
// 2.2: "SS_MSMod_10S_1C.mod" declare the parameter values. The computation of the steady state calls the function getk.m that computes the aggregate capital stock.
// 2.3: "Equations_10S_1C.mod" pass the model equations  
// 2.4: "Init_Val_MSMod_10S_1C.mod" specify the inital values that are computed in "SS_MSMod_MS_1C_NKM10.mod"
//*************************************************************************

// ######################################################################  

@#include "Vars_params_10S_1C.m"
     
@#include "SS_MSMod_10S_1C.mod" 

@#include "Equations_10S_1C.mod"

@#include "Init_Val_MSMod_10S_1C.mod"

// ######################################################################

// Since the number of equations can become large, it may be convenient to exploit Dynare's LaTeX-writing capabilities
write_latex_dynamic_model;

//*************************************************************************
// 3: Run checks
//*************************************************************************
model_diagnostics;
resid(1);
steady;
check;

//*************************************************************************
// 4: Solve model (potentially declare shocks, simulation paths,...)
// Here: Simulation under perfect Foresight
//*************************************************************************



shocks;
var shock_P_EM_a_t;
periods 
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26:500;
values 
0
0.0098834
0.0197669
0.0296504
0.0395339
0.0494174
0.04944338
0.04946936
0.04949534
0.04952132
0.0495473
0.06306842
0.07658954
0.09011066
0.10363178
0.1171529
0.10318514
0.08921738
0.07524962
0.06128186
0.0473141
0.046874
0.0464339
0.0459938
0.0455537
0.0451136; 


var shock_epsi_carb_int_a_t;
periods 
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26:500;

values 
0
-0.027965276
-0.055930552
-0.083895828
-0.111861104
-0.13982638
-0.166727168
-0.193627955
-0.220528743
-0.247429531
-0.274330319
-0.304111022
-0.333891725
-0.363672428
-0.39345313
-0.423233833
-0.440827206
-0.458420578
-0.47601395
-0.493607323
-0.511200695
-0.527660216
-0.544119737
-0.560579258
-0.577038779
-0.5934983
;


end;


simul(periods=600, maxit=20, stack_solve_algo=0);


