%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Rhe                                                           %
%    Nikolai Sthler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Rhe,                       %
%    Nikolai Sthler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//*************************************************************************
// 1: Define objects that are passed to Dynare's macro processor
//*************************************************************************

// Define the index of the country/countries used in the model.
@#define country    = ["a"]

//Specify the number of sectors included in the model.
@#define sector     = 10

//*************************************************************************
// 2: Declare the "usual suspects". Given the above specifications, Dynare's macroprocessor pre-processes the variables, parameters and shocks.
//
// 2.1: "Vars_params_10S_1C.m" specify model variables, exogenous shocks and parameters.
// 2.2: "SS_MSMod_10S_1C.mod" declare the parameter values. The computation of the steady state calls the function getk*.m that computes the aggregate capital stock.
// 2.3: "Equations_10S_1C.mod" pass the model equations  
// 2.4: "Init_Val_MSMod_10S_1C.mod" specify the inital values that are computed in "SS_MSMod_10S_1C.mod"
//*************************************************************************

// ######################################################################  

@#include "Vars_params_10S_1C.m"
     
@#include "SS_MSMod_10S_1C.mod" 

@#include "Equations_10S_1C.mod"

@#include "Init_Val_MSMod_10S_1C.mod"

// ######################################################################

// Since the number of equations can become large, it may be convenient to exploit Dynare's LaTeX-writing capabilities
write_latex_dynamic_model;


//*************************************************************************
// 3: Run checks
//*************************************************************************
model_diagnostics;
resid(1);
steady;
check;

//*************************************************************************
// 4: Declare shock size and solve model 
//*************************************************************************


shocks;
var shock_epsi_1_a_t;
stderr  0.01;
end;

stoch_simul(order=1,nograph) Y_VA_a_t C_a_t epsi_a_t w_a_t N_a_t I_a_t pi_cpi_a_t ZZ_a_t R_a_t;


conditional_forecast_paths;
 var Y_VA_a_t;
 periods 1:4;
 values 0.99985;
 end;
conditional_forecast(parameter_set=calibration, controlled_varexo = (shock_epsi_1_a_t));
//plot_conditional_forecast(periods = 20)  Y_VA_a_t ;


