%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Targets and parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

betta   = 0.992;                                                           // Discount factor                                          
sig     = 2;                                                               // Intertemporal elasticity of substitution
delta	= 0.025;                                                           // Depr. rate
Y_VA_a_ts  = 1;                                                            // Aggregate value added is normalized to 1

set_param_value('tfp_shocksize',tfp_shocksize);                            //Just for scaling purposes

@#for co in country
Country_Index = ismember(DSGE_country, {'@{co}'});                         // Match DSGE_country names with ISO country names in calibration
epsi_@{co}_ts = 1;                                                         // Aggregate TFP shock
epsi_carb_int_@{co}_ts = 1;                                                // Emissions intensity shock process

rho_eps_@{co}   = 0.8;                                                     // Persistence TFP shock
rho_eps_carb_int_@{co} = 0.8;                                              // Persistence emission intensity shock

lab_@{co}       = 2;                                                       // Inverse Frisch elasticity of labor supply

N_@{co}_ts      = 0.333;                                                   // Steady state hours -> 1/3 of time endowmwnt

PI_@{co}_ts = 1;                                                           // Relative price of investment basket (normalized to 1)

R_@{co}_ts  = 1/betta;                                                     // Nominal interest rate <-> real interest rate since gross inflation = 1

rk_@{co}_ts = PI_@{co}_ts/betta-(1-delta)*PI_@{co}_ts;                     // Real rental rate of capital

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Climate-related variables/parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rho_EM  = 1-0.9979;                                                        // Rate of decay wrt atmosph. carbon concentration

P_EM_@{co}_ts = 10^(-7);                                                   // Initial carbon price level

@#for se in [1:sector]                                                      
Sector_Index = DSGE_sector==@{se};  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_@{se}_@{co}', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, calibrated using 2005 data

gama1_@{se}_@{co}       = 0;            % Damage function parameter (proportional)
gama2_@{se}_@{co}       = 0;            % Damage function parameter (quadratic)
Pen_@{se}_@{co}_ts      = 0;            % Relative sectoral output loss
@#endfor                                                                    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Production parameters and elasticities of substitution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sigc_@{co}  = 1-1/0.9091;                                                  // Determines elasticity of substitution between sector-level consumption goods 
sigi_@{co}  = 1-1/0.7511;                                                  // Determines elasticity of substitution between sector-level investment goods 

upsi_K_@{co}= 2;                                                           // Determines the elasticity of substitution of capital across sectors
upsi_N_@{co}= 2;                                                           // Determines the elasticity of substitution of labor across sectors

Country_Index = ismember(DSGE_country, {'@{co}'}); % In order to match DSGE_country names with ISO country names in calibration 

@#for se in [1:sector]                                                     
Sector_Index = DSGE_sector==@{se};  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_@{se}_@{co}', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_@{se}_@{co}', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_@{se}_@{co}', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se
set_param_value('omega_K_tild_@{se}_@{co}', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se

set_param_value('Psi_con_@{se}_@{co}', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle
set_param_value('Psi_inv_@{se}_@{co}', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle
@#endfor

@#for se in [1:sector]                                                     
set_param_value('kappap_@{se}_@{co}', 75);                                  // Sticky price parameter
@#endfor
         
thetap_1_@{co}= 1.2/(1.2-1);
thetap_2_@{co}= 1.2/(1.2-1);
thetap_3_@{co}= 1.18/(1.18-1);
thetap_4_@{co}= 1.31/(1.31-1);
thetap_5_@{co}= 1.21/(1.21-1);
thetap_6_@{co}= 1.21/(1.21-1);
thetap_7_@{co}= 1.46/(1.46-1);
thetap_8_@{co}= 1.86/(1.86-1);
thetap_9_@{co}= 1.64/(1.64-1);
thetap_10_@{co}= 1.58/(1.58-1);
                                                                            
pi_cpi_@{co}_ts = 1;                                                       // Gross inflation rate

@#for se in [1:sector]                                                     
EM_cost_@{se}_@{co}_ts = P_EM_@{co}_ts*carb_int_@{se}_@{co};               // Ratio of nominal pollution cost and nominal sector output
mc_tild_@{se}_@{co}_ts = (thetap_@{se}_@{co}-1)/thetap_@{se}_@{co};
mc_@{se}_@{co}_ts = mc_tild_@{se}_@{co}_ts - EM_cost_@{se}_@{co}_ts;       // Real marginal production costs in each sector
P_@{se}_@{co}_ts = 1;                                                      // Output price of sector se
pi_ppi_@{se}_@{co}_ts = 1;                                                 // Producer price inflation in se
PH_@{se}_@{co}_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se
@#endfor                                                                   


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inter-sector trade shares
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@#for se in [1:sector]                                                     
Sector_Index = DSGE_sector==@{se};  % Match DSGE_sectors with NACE sector names in calibration

@#for se2 in [1:sector]
Sector2_Index = DSGE_sector==@{se2};
set_param_value('Psi_@{se}_@{se2}_@{co}', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se
@#endfor

@#endfor                                                                   

%% Substitution elasticities of intermediate goods bundle in sector se
@#for se in [1:sector]                                                     
sigh_@{se}_@{co} = 1-1/0.1;
@#endfor                                                                   


@#endfor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solving for the steady state values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

kk = getk( M_ , DSGE_sector, DSGE_country);
K_a_ts = kk(1);
H_1_1_a_ts =kk(2);
H_1_2_a_ts =kk(3);
H_1_3_a_ts =kk(4);
H_1_4_a_ts =kk(5);
H_1_5_a_ts =kk(6);
H_1_6_a_ts =kk(7);
H_1_7_a_ts =kk(8);
H_1_8_a_ts =kk(9);
H_1_9_a_ts =kk(10);
H_1_10_a_ts =kk(11);
H_2_1_a_ts =kk(12);
H_2_2_a_ts =kk(13);
H_2_3_a_ts =kk(14);
H_2_4_a_ts =kk(15);
H_2_5_a_ts =kk(16);
H_2_6_a_ts =kk(17);
H_2_7_a_ts =kk(18);
H_2_8_a_ts =kk(19);
H_2_9_a_ts =kk(20);
H_2_10_a_ts =kk(21);
H_3_1_a_ts =kk(22);
H_3_2_a_ts =kk(23);
H_3_3_a_ts =kk(24);
H_3_4_a_ts =kk(25);
H_3_5_a_ts =kk(26);
H_3_6_a_ts =kk(27);
H_3_7_a_ts =kk(28);
H_3_8_a_ts =kk(29);
H_3_9_a_ts =kk(30);
H_3_10_a_ts =kk(31);
H_4_1_a_ts =kk(32);
H_4_2_a_ts =kk(33);
H_4_3_a_ts =kk(34);
H_4_4_a_ts =kk(35);
H_4_5_a_ts =kk(36);
H_4_6_a_ts =kk(37);
H_4_7_a_ts =kk(38);
H_4_8_a_ts =kk(39);
H_4_9_a_ts =kk(40);
H_4_10_a_ts =kk(41);
H_5_1_a_ts =kk(42);
H_5_2_a_ts =kk(43);
H_5_3_a_ts =kk(44);
H_5_4_a_ts =kk(45);
H_5_5_a_ts =kk(46);
H_5_6_a_ts =kk(47);
H_5_7_a_ts =kk(48);
H_5_8_a_ts =kk(49);
H_5_9_a_ts =kk(50);
H_5_10_a_ts =kk(51);
H_6_1_a_ts =kk(52);
H_6_2_a_ts =kk(53);
H_6_3_a_ts =kk(54);
H_6_4_a_ts =kk(55);
H_6_5_a_ts =kk(56);
H_6_6_a_ts =kk(57);
H_6_7_a_ts =kk(58);
H_6_8_a_ts =kk(59);
H_6_9_a_ts =kk(60);
H_6_10_a_ts =kk(61);
H_7_1_a_ts =kk(62);
H_7_2_a_ts =kk(63);
H_7_3_a_ts =kk(64);
H_7_4_a_ts =kk(65);
H_7_5_a_ts =kk(66);
H_7_6_a_ts =kk(67);
H_7_7_a_ts =kk(68);
H_7_8_a_ts =kk(69);
H_7_9_a_ts =kk(70);
H_7_10_a_ts =kk(71);
H_8_1_a_ts =kk(72);
H_8_2_a_ts =kk(73);
H_8_3_a_ts =kk(74);
H_8_4_a_ts =kk(75);
H_8_5_a_ts =kk(76);
H_8_6_a_ts =kk(77);
H_8_7_a_ts =kk(78);
H_8_8_a_ts =kk(79);
H_8_9_a_ts =kk(80);
H_8_10_a_ts =kk(81);
H_9_1_a_ts =kk(82);
H_9_2_a_ts =kk(83);
H_9_3_a_ts =kk(84);
H_9_4_a_ts =kk(85);
H_9_5_a_ts =kk(86);
H_9_6_a_ts =kk(87);
H_9_7_a_ts =kk(88);
H_9_8_a_ts =kk(89);
H_9_9_a_ts =kk(90);
H_9_10_a_ts =kk(91);
H_10_1_a_ts =kk(92);
H_10_2_a_ts =kk(93);
H_10_3_a_ts =kk(94);
H_10_4_a_ts =kk(95);
H_10_5_a_ts =kk(96);
H_10_6_a_ts =kk(97);
H_10_7_a_ts =kk(98);
H_10_8_a_ts =kk(99);
H_10_9_a_ts =kk(100);
H_10_10_a_ts =kk(101);








@#for co in country

I_@{co}_ts = delta*K_@{co}_ts;
C_@{co}_ts = Y_VA_@{co}_ts - I_@{co}_ts;

@#for se in [1:sector]

C_@{se}_@{co}_ts = Psi_con_@{se}_@{co}*C_@{co}_ts;
I_@{se}_@{co}_ts = Psi_inv_@{se}_@{co}*I_@{co}_ts;

Y_@{se}_@{co}_ts = C_@{se}_@{co}_ts+I_@{se}_@{co}_ts + ( 
@#for se2 in [1:sector]
+H_@{se2}_@{se}_@{co}_ts
@#endfor
);

ZZ_@{se}_@{co}_ts = carb_int_@{se}_@{co}*Y_@{se}_@{co}_ts;

@#endfor
@#endfor


@#for co in country
ZZ_@{co}_ts =(
@#for se in [1:sector]
+ ZZ_@{se}_@{co}_ts
@#endfor
@#endfor
);


@#for co in country
Y_@{co}_ts =(
@#for se in [1:sector]
+ Y_@{se}_@{co}_ts
@#endfor
@#endfor
);



EM_ts = (
@#for co in country 
@#for se in [1:sector]
+ ZZ_@{se}_@{co}_ts
@#endfor
@#endfor
)/rho_EM;

@#for co in country
@#for se in [1:sector]

gama0_@{se}_@{co} =  Pen_@{se}_@{co}_ts - gama1_@{se}_@{co}*EM_ts - gama2_@{se}_@{co}*EM_ts^2;
   
K_@{se}_@{co}_ts = omega_K_tild_@{se}_@{co}*K_@{co}_ts;
rk_@{se}_@{co}_ts = alphaH_@{se}_@{co}*(1-alphaN_@{se}_@{co})*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/K_@{se}_@{co}_ts;
omega_K_@{se}_@{co} = omega_K_tild_@{se}_@{co} *(rk_@{se}_@{co}_ts/rk_@{co}_ts)^(1/(1-upsi_K_@{co}));                                    

H_@{se}_@{co}_ts = (1-alphaH_@{se}_@{co})*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/PH_@{se}_@{co}_ts;

@#endfor

w_@{co}_ts = (
@#for se in [1:sector]
+alphaH_@{se}_@{co}*alphaN_@{se}_@{co}*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/N_@{co}_ts
@#endfor
);

@#for se in [1:sector]
N_@{se}_@{co}_ts = omega_N_tild_@{se}_@{co}*N_@{co}_ts;
w_@{se}_@{co}_ts = alphaH_@{se}_@{co}*alphaN_@{se}_@{co}*mc_@{se}_@{co}_ts*Y_@{se}_@{co}_ts/N_@{se}_@{co}_ts;
omega_N_@{se}_@{co} = omega_N_tild_@{se}_@{co} *(w_@{se}_@{co}_ts/w_@{co}_ts)^(1/(1-upsi_N_@{co}));                                          

epsi_@{se}_@{co}_ts   = Y_@{se}_@{co}_ts/((1-Pen_@{se}_@{co}_ts)*(N_@{se}_@{co}_ts^alphaN_@{se}_@{co}*K_@{se}_@{co}_ts^(1-alphaN_@{se}_@{co}))^alphaH_@{se}_@{co}*H_@{se}_@{co}_ts^(1-alphaH_@{se}_@{co}));

@#endfor

lambda_@{co}_ts = C_@{co}_ts^(-sig);

kappaN_@{co}    = lambda_@{co}_ts*w_@{co}_ts/(N_@{co}_ts^lab_@{co});


@#endfor













