%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Röhe                                                           %
%    Nikolai Stähler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Röhe,                       %
%    Nikolai Stähler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Housekeeping
clear;
close all;
clc;
store_cd = cd;

%% Load simulation results from OS model 
cd OSModel\Results
load OS_CF_Results
cd(store_cd)

%% Load simulation results from MS model 
cd EMuSe\Results
load MS_CF_Results
cd(store_cd)

%% Plot figures 

sum_data = [100*MS_Y_VA_a_t_shock_epsi_a_t 100*OS_Y_a_t_shock_epsi_a_t 400*MS_pi_cpi_a_t_shock_epsi_a_t 400*OS_pi_cpi_a_t_shock_epsi_a_t];

f = figure;
subplot (2,1,1); 
   plot(1:1:size(MS_Y_VA_a_t_shock_epsi_a_t(1:end),1),  100*OS_Y_a_t_shock_epsi_a_t(1:end),'k--','LineWidth',1,'MarkerSize',3); hold on
   plot(1:1:size(MS_Y_VA_a_t_shock_epsi_a_t(1:end),1),  100*MS_Y_VA_a_t_shock_epsi_a_t(1:end) ,'r','LineWidth',1,'MarkerSize',3); hold off
   title('Real gross value added','FontSize',11,'FontWeight','Bold');
   xlabel ('Quarters');
   ylabel('Deviation from steady state, in %');

subplot (2,1,2); 
   plot(1:1:size(MS_Y_VA_a_t_shock_epsi_a_t(1:end),1), 400*OS_pi_cpi_a_t_shock_epsi_a_t(1:end), 'k--','LineWidth',1,'MarkerSize',3); hold on
   plot(1:1:size(MS_Y_VA_a_t_shock_epsi_a_t(1:end),1), 400*MS_pi_cpi_a_t_shock_epsi_a_t(1:end) ,'r','LineWidth',1,'MarkerSize',3); hold off
  title('Inflation rate','FontSize',11,'FontWeight','Bold');
   xlabel ('Quarters');   ylabel('annualised, in PP');
 
   
    h_legend=legend('OS Model','MS Model','Orientation','horizontal','Location','SouthOutside');
    pos = get(h_legend,'Position');
    pos(1) = 0.421428571428572;
    pos(2) = 0.0126738829072128;
    pos(3) = 0.186458333333333;
    pos(4) = 0.0373216245883644;
    set(h_legend,'Position',pos);
    set(h_legend,'FontSize',11,'FontWeight','Bold');
    sgtitle('Impact of an adverse supply shock, MS vs OS Model ');
 
    dim = [16,9];
    set(gcf,'paperpositionmode','manual','paperunits','inches');
    set(gcf,'papersize',dim,'paperposition',[0,0,dim]);
    print(gcf,'-dpdf','Figure_5_sticky_price');

