function [residual, g1, g2, g3] = OS_1C_Mod_simul_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(21, 1);
T78 = params(35)*y(28)/y(12);
T112 = 1-params(25)/2*(y(16)-1)^2;
T128 = y(8)^params(23);
T130 = y(1)^(1-params(23));
lhs =y(20);
rhs =params(15)+x(it_, 3);
residual(1)= lhs-rhs;
lhs =y(25);
rhs =(1-params(36))*y(5)+y(21);
residual(2)= lhs-rhs;
lhs =y(26);
rhs =y(25);
residual(3)= lhs-rhs;
lhs =y(22);
rhs =params(26)+y(25)*params(27)+params(28)*y(25)^2;
residual(4)= lhs-rhs;
lhs =y(21);
rhs =params(29)*y(13);
residual(5)= lhs-rhs;
lhs =log(y(14)/params(9));
rhs =params(30)*log(y(3)/params(9))+(1-params(30))*params(31)*log(y(15))+(1-params(30))*params(32)*log(y(13)/y(2));
residual(6)= lhs-rhs;
lhs =y(9);
rhs =(1-params(34))*y(1)+y(7);
residual(7)= lhs-rhs;
lhs =y(12);
rhs =y(6)^(-params(33));
residual(8)= lhs-rhs;
lhs =1;
rhs =y(14)*T78/y(30);
residual(9)= lhs-rhs;
lhs =1;
rhs =T78*(1-params(34)+y(27));
residual(10)= lhs-rhs;
lhs =y(12)*y(10);
rhs =params(20)*y(8)^params(21);
residual(11)= lhs-rhs;
lhs =y(7)+y(6);
rhs =y(1)*y(11)+y(10)*y(8)+y(13)*y(23)+y(19);
residual(12)= lhs-rhs;
lhs =y(19);
rhs =y(13)*T112-y(9)*y(11)-y(10)*y(8)-y(13)*params(29)*y(20)*(1+x(it_, 2));
residual(13)= lhs-rhs;
lhs =y(13);
rhs =y(18)*(1-y(22))*T128*T130;
residual(14)= lhs-rhs;
lhs =log(y(18)/params(13));
rhs =params(22)*log(y(4)/params(13))-x(it_, 1);
residual(15)= lhs-rhs;
lhs =y(23);
rhs =params(29)*y(20)*(1+x(it_, 2));
residual(16)= lhs-rhs;
lhs =y(24);
rhs =y(23)+y(17);
residual(17)= lhs-rhs;
lhs =y(15);
rhs =y(16);
residual(18)= lhs-rhs;
lhs =1-params(24)+y(24)*params(24)+y(31)*T78*params(25)*(y(31)-1)*y(29)/y(13);
rhs =y(16)*params(25)*(y(16)-1);
residual(19)= lhs-rhs;
lhs =y(10);
rhs =y(13)*params(23)*y(17)/y(8);
residual(20)= lhs-rhs;
lhs =y(11);
rhs =y(13)*(1-params(23))*y(17)/y(1);
residual(21)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(21, 34);

  %
  % Jacobian matrix
  %

T205 = (-(params(35)*y(28)))/(y(12)*y(12));
  g1(1,20)=1;
  g1(1,34)=(-1);
  g1(2,21)=(-1);
  g1(2,5)=(-(1-params(36)));
  g1(2,25)=1;
  g1(3,25)=(-1);
  g1(3,26)=1;
  g1(4,22)=1;
  g1(4,25)=(-(params(27)+params(28)*2*y(25)));
  g1(5,13)=(-params(29));
  g1(5,21)=1;
  g1(6,2)=(-((1-params(30))*params(32)*(-y(13))/(y(2)*y(2))/(y(13)/y(2))));
  g1(6,13)=(-((1-params(30))*params(32)*1/y(2)/(y(13)/y(2))));
  g1(6,3)=(-(params(30)*1/params(9)/(y(3)/params(9))));
  g1(6,14)=1/params(9)/(y(14)/params(9));
  g1(6,15)=(-((1-params(30))*params(31)*1/y(15)));
  g1(7,7)=(-1);
  g1(7,1)=(-(1-params(34)));
  g1(7,9)=1;
  g1(8,6)=(-(getPowerDeriv(y(6),(-params(33)),1)));
  g1(8,12)=1;
  g1(9,12)=(-(y(14)*T205/y(30)));
  g1(9,28)=(-(y(14)*params(35)/y(12)/y(30)));
  g1(9,14)=(-(T78/y(30)));
  g1(9,30)=(-((-(y(14)*T78))/(y(30)*y(30))));
  g1(10,27)=(-T78);
  g1(10,12)=(-((1-params(34)+y(27))*T205));
  g1(10,28)=(-((1-params(34)+y(27))*params(35)/y(12)));
  g1(11,8)=(-(params(20)*getPowerDeriv(y(8),params(21),1)));
  g1(11,10)=y(12);
  g1(11,12)=y(10);
  g1(12,6)=1;
  g1(12,7)=1;
  g1(12,8)=(-y(10));
  g1(12,1)=(-y(11));
  g1(12,10)=(-y(8));
  g1(12,11)=(-y(1));
  g1(12,13)=(-y(23));
  g1(12,19)=(-1);
  g1(12,23)=(-y(13));
  g1(13,8)=y(10);
  g1(13,9)=y(11);
  g1(13,10)=y(8);
  g1(13,11)=y(9);
  g1(13,13)=(-(T112-params(29)*y(20)*(1+x(it_, 2))));
  g1(13,16)=(-(y(13)*(-(params(25)/2*2*(y(16)-1)))));
  g1(13,19)=1;
  g1(13,20)=y(13)*params(29)*(1+x(it_, 2));
  g1(13,33)=y(13)*y(20)*params(29);
  g1(14,8)=(-(y(18)*(1-y(22))*T130*getPowerDeriv(y(8),params(23),1)));
  g1(14,1)=(-(y(18)*(1-y(22))*T128*getPowerDeriv(y(1),1-params(23),1)));
  g1(14,13)=1;
  g1(14,18)=(-((1-y(22))*T128*T130));
  g1(14,22)=(-(T128*T130*(-y(18))));
  g1(15,4)=(-(params(22)*1/params(13)/(y(4)/params(13))));
  g1(15,18)=1/params(13)/(y(18)/params(13));
  g1(15,32)=1;
  g1(16,20)=(-(params(29)*(1+x(it_, 2))));
  g1(16,23)=1;
  g1(16,33)=(-(y(20)*params(29)));
  g1(17,17)=(-1);
  g1(17,23)=(-1);
  g1(17,24)=1;
  g1(18,15)=1;
  g1(18,16)=(-1);
  g1(19,12)=y(29)*y(31)*(y(31)-1)*params(25)*T205/y(13);
  g1(19,28)=y(29)*y(31)*(y(31)-1)*params(25)*params(35)/y(12)/y(13);
  g1(19,13)=(-(y(31)*T78*params(25)*(y(31)-1)*y(29)))/(y(13)*y(13));
  g1(19,29)=y(31)*T78*params(25)*(y(31)-1)/y(13);
  g1(19,16)=(-(params(25)*(y(16)-1)+params(25)*y(16)));
  g1(19,31)=y(29)*(T78*params(25)*(y(31)-1)+T78*params(25)*y(31))/y(13);
  g1(19,24)=params(24);
  g1(20,8)=(-((-(y(13)*params(23)*y(17)))/(y(8)*y(8))));
  g1(20,10)=1;
  g1(20,13)=(-(params(23)*y(17)/y(8)));
  g1(20,17)=(-(y(13)*params(23)/y(8)));
  g1(21,1)=(-((-(y(13)*(1-params(23))*y(17)))/(y(1)*y(1))));
  g1(21,11)=1;
  g1(21,13)=(-((1-params(23))*y(17)/y(1)));
  g1(21,17)=(-(y(13)*(1-params(23))/y(1)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,1156);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,39304);
end
end
end
end
