function [residual, g1, g2, g3] = OS_1C_Mod_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 21, 1);

%
% Model equations
%

T67 = y(7)*params(35)/y(7);
T99 = 1-params(25)/2*(y(11)-1)^2;
T114 = y(3)^params(23);
T116 = y(4)^(1-params(23));
lhs =y(15);
rhs =params(15)+x(3);
residual(1)= lhs-rhs;
lhs =y(20);
rhs =y(20)*(1-params(36))+y(16);
residual(2)= lhs-rhs;
lhs =y(21);
rhs =y(20);
residual(3)= lhs-rhs;
lhs =y(17);
rhs =params(26)+y(20)*params(27)+params(28)*y(20)^2;
residual(4)= lhs-rhs;
lhs =y(16);
rhs =params(29)*y(8);
residual(5)= lhs-rhs;
lhs =log(y(9)/params(9));
rhs =log(y(9)/params(9))*params(30)+(1-params(30))*params(31)*log(y(10));
residual(6)= lhs-rhs;
lhs =y(4);
rhs =y(4)*(1-params(34))+y(2);
residual(7)= lhs-rhs;
lhs =y(7);
rhs =y(1)^(-params(33));
residual(8)= lhs-rhs;
lhs =1;
rhs =y(9)*T67/y(10);
residual(9)= lhs-rhs;
lhs =1;
rhs =T67*(1-params(34)+y(6));
residual(10)= lhs-rhs;
lhs =y(7)*y(5);
rhs =params(20)*y(3)^params(21);
residual(11)= lhs-rhs;
lhs =y(2)+y(1);
rhs =y(4)*y(6)+y(5)*y(3)+y(8)*y(18)+y(14);
residual(12)= lhs-rhs;
lhs =y(14);
rhs =y(8)*T99-y(4)*y(6)-y(5)*y(3)-y(8)*params(29)*y(15)*(1+x(2));
residual(13)= lhs-rhs;
lhs =y(8);
rhs =y(13)*(1-y(17))*T114*T116;
residual(14)= lhs-rhs;
lhs =log(y(13)/params(13));
rhs =log(y(13)/params(13))*params(22)-x(1);
residual(15)= lhs-rhs;
lhs =y(18);
rhs =params(29)*y(15)*(1+x(2));
residual(16)= lhs-rhs;
lhs =y(19);
rhs =y(18)+y(12);
residual(17)= lhs-rhs;
lhs =y(10);
rhs =y(11);
residual(18)= lhs-rhs;
lhs =1-params(24)+y(19)*params(24)+y(8)*y(11)*(y(11)-1)*T67*params(25)/y(8);
rhs =y(11)*params(25)*(y(11)-1);
residual(19)= lhs-rhs;
lhs =y(5);
rhs =y(8)*params(23)*y(12)/y(3);
residual(20)= lhs-rhs;
lhs =y(6);
rhs =y(8)*(1-params(23))*y(12)/y(4);
residual(21)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(21, 21);

  %
  % Jacobian matrix
  %

T193 = 1/params(9)/(y(9)/params(9));
T226 = 1/params(13)/(y(13)/params(13));
  g1(1,15)=1;
  g1(2,16)=(-1);
  g1(2,20)=1-(1-params(36));
  g1(3,20)=(-1);
  g1(3,21)=1;
  g1(4,17)=1;
  g1(4,20)=(-(params(27)+params(28)*2*y(20)));
  g1(5,8)=(-params(29));
  g1(5,16)=1;
  g1(6,9)=T193-params(30)*T193;
  g1(6,10)=(-((1-params(30))*params(31)*1/y(10)));
  g1(7,2)=(-1);
  g1(7,4)=1-(1-params(34));
  g1(8,1)=(-(getPowerDeriv(y(1),(-params(33)),1)));
  g1(8,7)=1;
  g1(9,9)=(-(T67/y(10)));
  g1(9,10)=(-((-(y(9)*T67))/(y(10)*y(10))));
  g1(10,6)=(-T67);
  g1(11,3)=(-(params(20)*getPowerDeriv(y(3),params(21),1)));
  g1(11,5)=y(7);
  g1(11,7)=y(5);
  g1(12,1)=1;
  g1(12,2)=1;
  g1(12,3)=(-y(5));
  g1(12,4)=(-y(6));
  g1(12,5)=(-y(3));
  g1(12,6)=(-y(4));
  g1(12,8)=(-y(18));
  g1(12,14)=(-1);
  g1(12,18)=(-y(8));
  g1(13,3)=y(5);
  g1(13,4)=y(6);
  g1(13,5)=y(3);
  g1(13,6)=y(4);
  g1(13,8)=(-(T99-params(29)*y(15)*(1+x(2))));
  g1(13,11)=(-(y(8)*(-(params(25)/2*2*(y(11)-1)))));
  g1(13,14)=1;
  g1(13,15)=y(8)*params(29)*(1+x(2));
  g1(14,3)=(-(y(13)*(1-y(17))*T116*getPowerDeriv(y(3),params(23),1)));
  g1(14,4)=(-(y(13)*(1-y(17))*T114*getPowerDeriv(y(4),1-params(23),1)));
  g1(14,8)=1;
  g1(14,13)=(-((1-y(17))*T114*T116));
  g1(14,17)=(-(T114*T116*(-y(13))));
  g1(15,13)=T226-params(22)*T226;
  g1(16,15)=(-(params(29)*(1+x(2))));
  g1(16,18)=1;
  g1(17,12)=(-1);
  g1(17,18)=(-1);
  g1(17,19)=1;
  g1(18,10)=1;
  g1(18,11)=(-1);
  g1(19,11)=y(8)*((y(11)-1)*T67*params(25)+y(11)*T67*params(25))/y(8)-(params(25)*(y(11)-1)+params(25)*y(11));
  g1(19,19)=params(24);
  g1(20,3)=(-((-(y(8)*params(23)*y(12)))/(y(3)*y(3))));
  g1(20,5)=1;
  g1(20,8)=(-(params(23)*y(12)/y(3)));
  g1(20,12)=(-(y(8)*params(23)/y(3)));
  g1(21,4)=(-((-(y(8)*(1-params(23))*y(12)))/(y(4)*y(4))));
  g1(21,6)=1;
  g1(21,8)=(-((1-params(23))*y(12)/y(4)));
  g1(21,12)=(-(y(8)*(1-params(23))/y(4)));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,441);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,9261);
end
end
end
end
