%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Targets and parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

betta   = 0.992;
sig     = 2;
delta	= 0.025;
taylor_r = 0.8;
taylor_dy = 0.15;
taylor_pi = 1.5;

Y_a_ts      = 1;
set_param_value('tfp_shocksize', tfp_shocksize);

@#for co in country

pi_cpi_@{co}_ts = 1;
pi_ppi_@{co}_@{co}_ts = 1;

rho_eps_@{co}   = 0.8;
lab_@{co}       = 2;

N_@{co}_ts      = 0.3538;

rk_@{co}_ts = 1/betta-(1-delta);

R_@{co}_ts  = 1/betta;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Climate-related variables/parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rho_EM  = 1-0.9979;

P_EM_@{co}_ts = 10^(-7);

carb_int_@{co} = 0.3538;

gama1_@{co}       = 0;  % Damage function parameter (proportional)
gama2_@{co}       = 0;  % Damage function parameter (quadratic)
Pen_@{co}_ts      = 0;  % Relative sectoral output loss 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Production parameters and elasticities of substitution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

alphaN_@{co} = 0.67;

%Price adjustment costs and markups
kappap_@{co} = 75;                 % Note: Calibrated by averaging kappas across sectors.
thetap_@{co} = 1.3850/.3850;       % Note: Calibrated by averaging markups across sectors.

EM_cost_@{co}_ts = P_EM_@{co}_ts*carb_int_@{co};
mc_tild_@{co}_ts = (thetap_@{co}-1)/thetap_@{co};
mc_@{co}_ts = mc_tild_@{co}_ts - EM_cost_@{co}_ts;


@#endfor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solving the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


@#for co in country

K_@{co}_ts = (1-alphaN_@{co})*mc_@{co}_ts*Y_@{co}_ts/rk_@{co}_ts;
I_@{co}_ts = delta*K_@{co}_ts;
C_@{co}_ts = Y_@{co}_ts - I_@{co}_ts;

ZZ_@{co}_ts = carb_int_@{co}*Y_@{co}_ts;

EM_@{co}_ts = ( ZZ_@{co}_ts)/rho_EM;
@#endfor


EM_ts = (
@#for co in country 
+ EM_@{co}_ts
@#endfor
);


@#for co in country
gama0_@{co} =  Pen_@{co}_ts - gama1_@{co}*EM_@{co}_ts - gama2_@{co}*EM_@{co}_ts^2;

w_@{co}_ts  = alphaN_@{co}*mc_@{co}_ts*Y_@{co}_ts/N_@{co}_ts;

profits_@{co}_ts = Y_@{co}_ts - rk_@{co}_ts * K_@{co}_ts - w_@{co}_ts * N_@{co}_ts - P_EM_@{co}_ts * carb_int_@{co} * Y_a_ts;

C_@{co}_ts = K_@{co}_ts * rk_@{co}_ts + w_@{co}_ts * N_@{co}_ts + EM_cost_@{co}_ts * Y_@{co}_ts + profits_@{co}_ts - I_@{co}_ts;

epsi_@{co}_ts   = Y_@{co}_ts/( (1-Pen_@{co}_ts)*(N_@{co}_ts^alphaN_@{co}*K_@{co}_ts^(1-alphaN_@{co})) );

lambda_@{co}_ts = C_@{co}_ts^(-sig);

kappaN_@{co} = (lambda_@{co}_ts*w_@{co}_ts)/(N_@{co}_ts^lab_@{co});
@#endfor


