@#line "MS_1C_Mod_simul.mod" 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Rhe                                                           %
%    Nikolai Sthler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Rhe,                       %
%    Nikolai Sthler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//************************************************************
// 1: Define objects that are passed to Dynare's macro processor
//************************************************************

// Define the index of the country/countries used in the model.


// Specify the number of sectors included in the model.


//************************************************************
// 2: Declare the "usual suspects". Given the above specifications, Dynare's macroprocessor pre-processes the variables, parameters and shocks.
//
// 2.1: "Vars_params_10S_1C.m" specify model variables, exogenous shocks and parameters.
// 2.2: "SS_MSMod_10S_1C.mod" declare the parameter values. The computation of the steady state calls the function getk.m that computes the aggregate capital stock.
// 2.3: "Equations_10S_1C.mod" pass the model equations  
// 2.4: "Init_Val_MSMod_10S_1C.mod" specify the inital values that are computed in "SS_MSMod_10S_1C.mod"
//************************************************************

// ######################################################################  


@#line "Vars_params_10S_1C.m" 1
var     

@#line "Vars_params_10S_1C.m" 3
        C_a_t, I_a_t, N_a_t, K_a_t, w_a_t,
        rk_a_t, lambda_a_t, Y_a_t, Y_VA_a_t, PI_a_t,
        R_a_t, pi_cpi_a_t, epsi_a_t, ZZ_a_t,  P_EM_a_t, 
        

@#line "Vars_params_10S_1C.m" 8
        C_1_a_t, I_1_a_t, N_1_a_t, K_1_a_t, Y_1_a_t,
        w_1_a_t, epsi_1_a_t, rk_1_a_t, H_1_a_t,
        PH_1_a_t, P_1_a_t, pi_ppi_1_a_t,
        mc_1_a_t, 
        
        ZZ_1_a_t, Pen_1_a_t, EM_cost_1_a_t, mc_tild_1_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_1_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_1_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_2_a_t, I_2_a_t, N_2_a_t, K_2_a_t, Y_2_a_t,
        w_2_a_t, epsi_2_a_t, rk_2_a_t, H_2_a_t,
        PH_2_a_t, P_2_a_t, pi_ppi_2_a_t,
        mc_2_a_t, 
        
        ZZ_2_a_t, Pen_2_a_t, EM_cost_2_a_t, mc_tild_2_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_2_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_2_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_3_a_t, I_3_a_t, N_3_a_t, K_3_a_t, Y_3_a_t,
        w_3_a_t, epsi_3_a_t, rk_3_a_t, H_3_a_t,
        PH_3_a_t, P_3_a_t, pi_ppi_3_a_t,
        mc_3_a_t, 
        
        ZZ_3_a_t, Pen_3_a_t, EM_cost_3_a_t, mc_tild_3_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_3_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_3_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_4_a_t, I_4_a_t, N_4_a_t, K_4_a_t, Y_4_a_t,
        w_4_a_t, epsi_4_a_t, rk_4_a_t, H_4_a_t,
        PH_4_a_t, P_4_a_t, pi_ppi_4_a_t,
        mc_4_a_t, 
        
        ZZ_4_a_t, Pen_4_a_t, EM_cost_4_a_t, mc_tild_4_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_4_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_4_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_5_a_t, I_5_a_t, N_5_a_t, K_5_a_t, Y_5_a_t,
        w_5_a_t, epsi_5_a_t, rk_5_a_t, H_5_a_t,
        PH_5_a_t, P_5_a_t, pi_ppi_5_a_t,
        mc_5_a_t, 
        
        ZZ_5_a_t, Pen_5_a_t, EM_cost_5_a_t, mc_tild_5_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_5_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_5_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_6_a_t, I_6_a_t, N_6_a_t, K_6_a_t, Y_6_a_t,
        w_6_a_t, epsi_6_a_t, rk_6_a_t, H_6_a_t,
        PH_6_a_t, P_6_a_t, pi_ppi_6_a_t,
        mc_6_a_t, 
        
        ZZ_6_a_t, Pen_6_a_t, EM_cost_6_a_t, mc_tild_6_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_6_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_6_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_7_a_t, I_7_a_t, N_7_a_t, K_7_a_t, Y_7_a_t,
        w_7_a_t, epsi_7_a_t, rk_7_a_t, H_7_a_t,
        PH_7_a_t, P_7_a_t, pi_ppi_7_a_t,
        mc_7_a_t, 
        
        ZZ_7_a_t, Pen_7_a_t, EM_cost_7_a_t, mc_tild_7_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_7_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_7_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_8_a_t, I_8_a_t, N_8_a_t, K_8_a_t, Y_8_a_t,
        w_8_a_t, epsi_8_a_t, rk_8_a_t, H_8_a_t,
        PH_8_a_t, P_8_a_t, pi_ppi_8_a_t,
        mc_8_a_t, 
        
        ZZ_8_a_t, Pen_8_a_t, EM_cost_8_a_t, mc_tild_8_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_8_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_8_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_9_a_t, I_9_a_t, N_9_a_t, K_9_a_t, Y_9_a_t,
        w_9_a_t, epsi_9_a_t, rk_9_a_t, H_9_a_t,
        PH_9_a_t, P_9_a_t, pi_ppi_9_a_t,
        mc_9_a_t, 
        
        ZZ_9_a_t, Pen_9_a_t, EM_cost_9_a_t, mc_tild_9_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_9_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_9_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 8
        C_10_a_t, I_10_a_t, N_10_a_t, K_10_a_t, Y_10_a_t,
        w_10_a_t, epsi_10_a_t, rk_10_a_t, H_10_a_t,
        PH_10_a_t, P_10_a_t, pi_ppi_10_a_t,
        mc_10_a_t, 
        
        ZZ_10_a_t, Pen_10_a_t, EM_cost_10_a_t, mc_tild_10_a_t,
        

@#line "Vars_params_10S_1C.m" 16
        H_10_1_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_2_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_3_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_4_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_5_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_6_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_7_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_8_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_9_a_t, 

@#line "Vars_params_10S_1C.m" 16
        H_10_10_a_t, 

@#line "Vars_params_10S_1C.m" 18
        

@#line "Vars_params_10S_1C.m" 20

@#line "Vars_params_10S_1C.m" 21
        
        EM_t
        ;
        
        
varexo

@#line "Vars_params_10S_1C.m" 28
        shock_epsi_a_t, shock_P_EM_a_t, shock_epsi_carb_int_a_t,    

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_1_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_2_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_3_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_4_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_5_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_6_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_7_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_8_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_9_a_t 

@#line "Vars_params_10S_1C.m" 30
        shock_epsi_10_a_t 

@#line "Vars_params_10S_1C.m" 32

@#line "Vars_params_10S_1C.m" 33
        ;
        


parameters  

@#line "Vars_params_10S_1C.m" 39
        C_a_ts, I_a_ts, N_a_ts, K_a_ts, w_a_ts,
        rk_a_ts, lambda_a_ts, Y_a_ts, Y_VA_a_ts, PI_a_ts,
        R_a_ts, pi_cpi_a_ts,
            
        kappaN_a, lab_a, rho_eps_a, rho_eps_carb_int_a,
        
        epsi_a_ts,  ZZ_a_ts,  P_EM_a_ts,
        

@#line "Vars_params_10S_1C.m" 48
        C_1_a_ts, I_1_a_ts, N_1_a_ts, K_1_a_ts, Y_1_a_ts,
        w_1_a_ts, epsi_1_a_ts, rk_1_a_ts, H_1_a_ts,
        PH_1_a_ts, P_1_a_ts, pi_ppi_1_a_ts,
        mc_1_a_ts, 
        
        ZZ_1_a_ts, Pen_1_a_ts, EM_cost_1_a_ts, mc_tild_1_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_1_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_1_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_1_a, Psi_inv_1_a, omega_N_1_a, omega_K_1_a, omega_N_tild_1_a, omega_K_tild_1_a,
        sigh_1_a, alphaH_1_a, alphaN_1_a,
      
        gama0_1_a, gama1_1_a, gama2_1_a, carb_int_1_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_1_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_1_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_2_a_ts, I_2_a_ts, N_2_a_ts, K_2_a_ts, Y_2_a_ts,
        w_2_a_ts, epsi_2_a_ts, rk_2_a_ts, H_2_a_ts,
        PH_2_a_ts, P_2_a_ts, pi_ppi_2_a_ts,
        mc_2_a_ts, 
        
        ZZ_2_a_ts, Pen_2_a_ts, EM_cost_2_a_ts, mc_tild_2_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_2_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_2_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_2_a, Psi_inv_2_a, omega_N_2_a, omega_K_2_a, omega_N_tild_2_a, omega_K_tild_2_a,
        sigh_2_a, alphaH_2_a, alphaN_2_a,
      
        gama0_2_a, gama1_2_a, gama2_2_a, carb_int_2_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_2_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_2_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_3_a_ts, I_3_a_ts, N_3_a_ts, K_3_a_ts, Y_3_a_ts,
        w_3_a_ts, epsi_3_a_ts, rk_3_a_ts, H_3_a_ts,
        PH_3_a_ts, P_3_a_ts, pi_ppi_3_a_ts,
        mc_3_a_ts, 
        
        ZZ_3_a_ts, Pen_3_a_ts, EM_cost_3_a_ts, mc_tild_3_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_3_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_3_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_3_a, Psi_inv_3_a, omega_N_3_a, omega_K_3_a, omega_N_tild_3_a, omega_K_tild_3_a,
        sigh_3_a, alphaH_3_a, alphaN_3_a,
      
        gama0_3_a, gama1_3_a, gama2_3_a, carb_int_3_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_3_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_3_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_4_a_ts, I_4_a_ts, N_4_a_ts, K_4_a_ts, Y_4_a_ts,
        w_4_a_ts, epsi_4_a_ts, rk_4_a_ts, H_4_a_ts,
        PH_4_a_ts, P_4_a_ts, pi_ppi_4_a_ts,
        mc_4_a_ts, 
        
        ZZ_4_a_ts, Pen_4_a_ts, EM_cost_4_a_ts, mc_tild_4_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_4_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_4_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_4_a, Psi_inv_4_a, omega_N_4_a, omega_K_4_a, omega_N_tild_4_a, omega_K_tild_4_a,
        sigh_4_a, alphaH_4_a, alphaN_4_a,
      
        gama0_4_a, gama1_4_a, gama2_4_a, carb_int_4_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_4_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_4_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_5_a_ts, I_5_a_ts, N_5_a_ts, K_5_a_ts, Y_5_a_ts,
        w_5_a_ts, epsi_5_a_ts, rk_5_a_ts, H_5_a_ts,
        PH_5_a_ts, P_5_a_ts, pi_ppi_5_a_ts,
        mc_5_a_ts, 
        
        ZZ_5_a_ts, Pen_5_a_ts, EM_cost_5_a_ts, mc_tild_5_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_5_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_5_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_5_a, Psi_inv_5_a, omega_N_5_a, omega_K_5_a, omega_N_tild_5_a, omega_K_tild_5_a,
        sigh_5_a, alphaH_5_a, alphaN_5_a,
      
        gama0_5_a, gama1_5_a, gama2_5_a, carb_int_5_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_5_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_5_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_6_a_ts, I_6_a_ts, N_6_a_ts, K_6_a_ts, Y_6_a_ts,
        w_6_a_ts, epsi_6_a_ts, rk_6_a_ts, H_6_a_ts,
        PH_6_a_ts, P_6_a_ts, pi_ppi_6_a_ts,
        mc_6_a_ts, 
        
        ZZ_6_a_ts, Pen_6_a_ts, EM_cost_6_a_ts, mc_tild_6_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_6_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_6_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_6_a, Psi_inv_6_a, omega_N_6_a, omega_K_6_a, omega_N_tild_6_a, omega_K_tild_6_a,
        sigh_6_a, alphaH_6_a, alphaN_6_a,
      
        gama0_6_a, gama1_6_a, gama2_6_a, carb_int_6_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_6_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_6_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_7_a_ts, I_7_a_ts, N_7_a_ts, K_7_a_ts, Y_7_a_ts,
        w_7_a_ts, epsi_7_a_ts, rk_7_a_ts, H_7_a_ts,
        PH_7_a_ts, P_7_a_ts, pi_ppi_7_a_ts,
        mc_7_a_ts, 
        
        ZZ_7_a_ts, Pen_7_a_ts, EM_cost_7_a_ts, mc_tild_7_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_7_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_7_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_7_a, Psi_inv_7_a, omega_N_7_a, omega_K_7_a, omega_N_tild_7_a, omega_K_tild_7_a,
        sigh_7_a, alphaH_7_a, alphaN_7_a,
      
        gama0_7_a, gama1_7_a, gama2_7_a, carb_int_7_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_7_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_7_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_8_a_ts, I_8_a_ts, N_8_a_ts, K_8_a_ts, Y_8_a_ts,
        w_8_a_ts, epsi_8_a_ts, rk_8_a_ts, H_8_a_ts,
        PH_8_a_ts, P_8_a_ts, pi_ppi_8_a_ts,
        mc_8_a_ts, 
        
        ZZ_8_a_ts, Pen_8_a_ts, EM_cost_8_a_ts, mc_tild_8_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_8_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_8_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_8_a, Psi_inv_8_a, omega_N_8_a, omega_K_8_a, omega_N_tild_8_a, omega_K_tild_8_a,
        sigh_8_a, alphaH_8_a, alphaN_8_a,
      
        gama0_8_a, gama1_8_a, gama2_8_a, carb_int_8_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_8_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_8_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_9_a_ts, I_9_a_ts, N_9_a_ts, K_9_a_ts, Y_9_a_ts,
        w_9_a_ts, epsi_9_a_ts, rk_9_a_ts, H_9_a_ts,
        PH_9_a_ts, P_9_a_ts, pi_ppi_9_a_ts,
        mc_9_a_ts, 
        
        ZZ_9_a_ts, Pen_9_a_ts, EM_cost_9_a_ts, mc_tild_9_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_9_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_9_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_9_a, Psi_inv_9_a, omega_N_9_a, omega_K_9_a, omega_N_tild_9_a, omega_K_tild_9_a,
        sigh_9_a, alphaH_9_a, alphaN_9_a,
      
        gama0_9_a, gama1_9_a, gama2_9_a, carb_int_9_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_9_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_9_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 48
        C_10_a_ts, I_10_a_ts, N_10_a_ts, K_10_a_ts, Y_10_a_ts,
        w_10_a_ts, epsi_10_a_ts, rk_10_a_ts, H_10_a_ts,
        PH_10_a_ts, P_10_a_ts, pi_ppi_10_a_ts,
        mc_10_a_ts, 
        
        ZZ_10_a_ts, Pen_10_a_ts, EM_cost_10_a_ts, mc_tild_10_a_ts,
        

@#line "Vars_params_10S_1C.m" 56
        H_10_1_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_2_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_3_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_4_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_5_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_6_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_7_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_8_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_9_a_ts,

@#line "Vars_params_10S_1C.m" 56
        H_10_10_a_ts,

@#line "Vars_params_10S_1C.m" 58
        
        Psi_con_10_a, Psi_inv_10_a, omega_N_10_a, omega_K_10_a, omega_N_tild_10_a, omega_K_tild_10_a,
        sigh_10_a, alphaH_10_a, alphaN_10_a,
      
        gama0_10_a, gama1_10_a, gama2_10_a, carb_int_10_a,
      

@#line "Vars_params_10S_1C.m" 65
        Psi_10_1_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_2_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_3_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_4_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_5_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_6_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_7_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_8_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_9_a,

@#line "Vars_params_10S_1C.m" 65
        Psi_10_10_a,

@#line "Vars_params_10S_1C.m" 67

@#line "Vars_params_10S_1C.m" 68
        sigc_a, sigi_a, upsi_K_a, upsi_N_a,
     

@#line "Vars_params_10S_1C.m" 71
        
        sig, delta, betta, rho_EM, EM_ts
        ;
@#line "MS_1C_Mod_simul.mod" 72
     

@#line "SS_MSMod_10S_1C.mod" 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Targets and parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

betta   = 0.992^4;                                                         // Discount factor                                          
sig     = 2;                                                               // Intertemporal elasticity of substitution
delta	= 0.025*4;                                                         // Depr. rate
Y_VA_a_ts      = 1;                                                        // Aggregate value added is normalized to 1


@#line "SS_MSMod_10S_1C.mod" 11
Country_Index = ismember(DSGE_country, {'a'});                         // Match DSGE_country names with ISO country names in calibration
epsi_a_ts = 1;                                                         // Aggregate TFP shock
epsi_carb_int_a_ts = 1;                                                // Emissions intensity shock process

rho_eps_a   = 0.8^4;                                                   // Persistence TFP shock
rho_eps_carb_int_a = 0.8^4;                                            // Persistence emission intensity shock

lab_a       = 2;                                                       // Inverse Frisch elasticity of labor supply

N_a_ts      = 0.333;                                                   // Steady state hours -> 1/3 of time endowment

PI_a_ts = 1;                                                           // Relative price of investment basket (normalized to 1)

R_a_ts  = 1/betta;                                                     // Nominal interest rate <-> real interest rate since gross inflation = 1

rk_a_ts = PI_a_ts/betta-(1-delta)*PI_a_ts;                     // Real rental rate of capital

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Climate-related variables/parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rho_EM  = 1-0.9979^4;                                                      // Rate of decay wrt atmosph. carbon concentration

P_EM_a_ts = 10^(-7);                                                   // Initial carbon price level


@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==1;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_1_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_1_a       = 0;            % Damage function parameter (proportional)
gama2_1_a       = 0;            % Damage function parameter (quadratic)
Pen_1_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==2;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_2_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_2_a       = 0;            % Damage function parameter (proportional)
gama2_2_a       = 0;            % Damage function parameter (quadratic)
Pen_2_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==3;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_3_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_3_a       = 0;            % Damage function parameter (proportional)
gama2_3_a       = 0;            % Damage function parameter (quadratic)
Pen_3_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==4;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_4_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_4_a       = 0;            % Damage function parameter (proportional)
gama2_4_a       = 0;            % Damage function parameter (quadratic)
Pen_4_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==5;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_5_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_5_a       = 0;            % Damage function parameter (proportional)
gama2_5_a       = 0;            % Damage function parameter (quadratic)
Pen_5_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==6;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_6_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_6_a       = 0;            % Damage function parameter (proportional)
gama2_6_a       = 0;            % Damage function parameter (quadratic)
Pen_6_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==7;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_7_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_7_a       = 0;            % Damage function parameter (proportional)
gama2_7_a       = 0;            % Damage function parameter (quadratic)
Pen_7_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==8;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_8_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_8_a       = 0;            % Damage function parameter (proportional)
gama2_8_a       = 0;            % Damage function parameter (quadratic)
Pen_8_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==9;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_9_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_9_a       = 0;            % Damage function parameter (proportional)
gama2_9_a       = 0;            % Damage function parameter (quadratic)
Pen_9_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 37
Sector_Index = DSGE_sector==10;  % In order to match DSGE_sectors with NACE sector names in calibration

// Constant emission per unit of output:
set_param_value('carb_int_10_a', Calibration.Emissions.Const_frac.(ISO{Country_Index}){NACE(Sector_Index),6});    % Emissions per unit of output, specified using the value of 2005

gama1_10_a       = 0;            % Damage function parameter (proportional)
gama2_10_a       = 0;            % Damage function parameter (quadratic)
Pen_10_a_ts      = 0;            % Relative sectoral output loss

@#line "SS_MSMod_10S_1C.mod" 46

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Production parameters and elasticities of substitution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sigc_a  = 1-1/0.9091;                                                  // Determines elasticity of substitution between sector-level consumption goods (1/(1-sigc_a)=0.901)
sigi_a  = 1-1/0.7511;                                                  // Determines elasticity of substitution between sector-level investment goods (1/(1-sigi_a)=0.7511)

upsi_K_a= 2;                                                           // Determines the elasticity of substitution of capital across sectors, taken from Bouakez et al. (2023) )
upsi_N_a= 2;                                                           // Determines the elasticity of substitution of labor across sectors, taken from Bouakez et al. (2023))

Country_Index = ismember(DSGE_country, {'a'}); % In order to match DSGE_country names with ISO country names in calibration 


@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==1;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_1_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_1_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_1_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_1_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==2;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_2_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_2_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_2_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_2_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==3;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_3_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_3_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_3_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_3_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==4;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_4_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_4_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_4_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_4_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==5;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_5_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_5_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_5_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_5_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==6;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_6_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_6_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_6_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_6_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==7;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_7_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_7_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_7_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_7_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==8;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_8_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_8_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_8_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_8_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==9;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_9_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_9_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_9_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_9_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 60
Sector_Index = DSGE_sector==10;  % In order to match DSGE_sectors with NACE sector names in calibration

set_param_value('alphaN_10_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_N(6,:)); // Elasticity of output wrt labor (calibrated to WIOD 2005 data)
set_param_value('alphaH_10_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).alpha_H(6,:)); // Elasticity of output wrt intermediate-goods (calibrated to WIOD 2005 data)

set_param_value('omega_N_tild_10_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_N(6,:)); // Weight attached to labor provided to sector se, specified using the value of 2005
set_param_value('omega_K_tild_10_a', Calibration.SEA.(ISO{Country_Index}).(NACE(Sector_Index)).omega_K(6,:)); // Weight attached to capital provided to sector se, specified using the value of 2005

set_param_value('Psi_con_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_C'});  // Sectoral shares in the consumption good bundle, specified using the value of 2005
set_param_value('Psi_inv_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).NA.Psi_C_I_G{NACE(Sector_Index), 'Psi_I'});  // Sectoral shares in the investment good bundle, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 71

pi_cpi_a_ts = 1;                                                       // Gross inflation rate (normalized to 1)


@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_1_a_ts = P_EM_a_ts*carb_int_1_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_1_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_1_a_ts = mc_tild_1_a_ts - EM_cost_1_a_ts;       // Real marginal production costs in each sector
P_1_a_ts = 1;                                                      // Output price of sector se
pi_ppi_1_a_ts = 1;                                                 // Producer price inflation in se
PH_1_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_2_a_ts = P_EM_a_ts*carb_int_2_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_2_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_2_a_ts = mc_tild_2_a_ts - EM_cost_2_a_ts;       // Real marginal production costs in each sector
P_2_a_ts = 1;                                                      // Output price of sector se
pi_ppi_2_a_ts = 1;                                                 // Producer price inflation in se
PH_2_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_3_a_ts = P_EM_a_ts*carb_int_3_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_3_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_3_a_ts = mc_tild_3_a_ts - EM_cost_3_a_ts;       // Real marginal production costs in each sector
P_3_a_ts = 1;                                                      // Output price of sector se
pi_ppi_3_a_ts = 1;                                                 // Producer price inflation in se
PH_3_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_4_a_ts = P_EM_a_ts*carb_int_4_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_4_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_4_a_ts = mc_tild_4_a_ts - EM_cost_4_a_ts;       // Real marginal production costs in each sector
P_4_a_ts = 1;                                                      // Output price of sector se
pi_ppi_4_a_ts = 1;                                                 // Producer price inflation in se
PH_4_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_5_a_ts = P_EM_a_ts*carb_int_5_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_5_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_5_a_ts = mc_tild_5_a_ts - EM_cost_5_a_ts;       // Real marginal production costs in each sector
P_5_a_ts = 1;                                                      // Output price of sector se
pi_ppi_5_a_ts = 1;                                                 // Producer price inflation in se
PH_5_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_6_a_ts = P_EM_a_ts*carb_int_6_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_6_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_6_a_ts = mc_tild_6_a_ts - EM_cost_6_a_ts;       // Real marginal production costs in each sector
P_6_a_ts = 1;                                                      // Output price of sector se
pi_ppi_6_a_ts = 1;                                                 // Producer price inflation in se
PH_6_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_7_a_ts = P_EM_a_ts*carb_int_7_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_7_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_7_a_ts = mc_tild_7_a_ts - EM_cost_7_a_ts;       // Real marginal production costs in each sector
P_7_a_ts = 1;                                                      // Output price of sector se
pi_ppi_7_a_ts = 1;                                                 // Producer price inflation in se
PH_7_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_8_a_ts = P_EM_a_ts*carb_int_8_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_8_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_8_a_ts = mc_tild_8_a_ts - EM_cost_8_a_ts;       // Real marginal production costs in each sector
P_8_a_ts = 1;                                                      // Output price of sector se
pi_ppi_8_a_ts = 1;                                                 // Producer price inflation in se
PH_8_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_9_a_ts = P_EM_a_ts*carb_int_9_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_9_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_9_a_ts = mc_tild_9_a_ts - EM_cost_9_a_ts;       // Real marginal production costs in each sector
P_9_a_ts = 1;                                                      // Output price of sector se
pi_ppi_9_a_ts = 1;                                                 // Producer price inflation in se
PH_9_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 75
EM_cost_10_a_ts = P_EM_a_ts*carb_int_10_a;               // Ratio of nominal pollution cost and nominal sector output
mc_tild_10_a_ts = 1;                                                // Marginal costs relevant for pricing also include abatement costs and emissions taxes
mc_10_a_ts = mc_tild_10_a_ts - EM_cost_10_a_ts;       // Real marginal production costs in each sector
P_10_a_ts = 1;                                                      // Output price of sector se
pi_ppi_10_a_ts = 1;                                                 // Producer price inflation in se
PH_10_a_ts = 1;                                                     // Price level of intermediate goods bundle used in sector se

@#line "SS_MSMod_10S_1C.mod" 82


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inter-sector trade shares
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==1;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_1_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_1_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_1_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_1_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_1_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_1_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_1_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_1_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_1_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_1_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==2;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_2_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_2_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_2_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_2_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_2_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_2_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_2_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_2_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_2_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_2_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==3;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_3_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_3_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_3_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_3_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_3_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_3_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_3_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_3_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_3_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_3_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==4;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_4_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_4_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_4_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_4_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_4_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_4_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_4_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_4_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_4_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_4_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==5;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_5_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_5_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_5_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_5_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_5_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_5_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_5_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_5_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_5_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_5_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==6;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_6_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_6_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_6_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_6_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_6_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_6_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_6_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_6_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_6_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_6_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==7;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_7_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_7_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_7_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_7_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_7_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_7_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_7_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_7_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_7_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_7_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==8;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_8_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_8_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_8_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_8_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_8_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_8_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_8_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_8_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_8_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_8_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==9;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_9_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_9_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_9_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_9_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_9_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_9_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_9_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_9_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_9_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_9_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 88
Sector_Index = DSGE_sector==10;  % Match DSGE_sectors with NACE sector names in calibration


@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==1;
set_param_value('Psi_10_1_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==2;
set_param_value('Psi_10_2_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==3;
set_param_value('Psi_10_3_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==4;
set_param_value('Psi_10_4_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==5;
set_param_value('Psi_10_5_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==6;
set_param_value('Psi_10_6_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==7;
set_param_value('Psi_10_7_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==8;
set_param_value('Psi_10_8_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==9;
set_param_value('Psi_10_9_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 91
Sector2_Index = DSGE_sector==10;
set_param_value('Psi_10_10_a', Calibration.WIOD.y05.(ISO{Country_Index}).IO.Psi_H{NACE(Sector2_Index), NACE(Sector_Index)}); // Weighting parameter for intermediate goods -> share of se2 used in H_se, specified using the value of 2005

@#line "SS_MSMod_10S_1C.mod" 94


@#line "SS_MSMod_10S_1C.mod" 96

%% Substitution elasticities of intermediate goods bundle in sector se
sigh_1_a = 1-1/0.1;
sigh_2_a = 1-1/0.1;
sigh_3_a = 1-1/0.1;
sigh_4_a = 1-1/0.1;
sigh_5_a = 1-1/0.1; 
sigh_6_a = 1-1/0.1;
sigh_7_a = 1-1/0.1;
sigh_8_a = 1-1/0.1;
sigh_9_a = 1-1/0.1;
sigh_10_a= 1-1/0.1;


@#line "SS_MSMod_10S_1C.mod" 110

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solving for the steady state values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

kk = getk( M_ , DSGE_sector, DSGE_country);
K_a_ts = kk(1);
H_1_1_a_ts =kk(2);
H_1_2_a_ts =kk(3);
H_1_3_a_ts =kk(4);
H_1_4_a_ts =kk(5);
H_1_5_a_ts =kk(6);
H_1_6_a_ts =kk(7);
H_1_7_a_ts =kk(8);
H_1_8_a_ts =kk(9);
H_1_9_a_ts =kk(10);
H_1_10_a_ts =kk(11);
H_2_1_a_ts =kk(12);
H_2_2_a_ts =kk(13);
H_2_3_a_ts =kk(14);
H_2_4_a_ts =kk(15);
H_2_5_a_ts =kk(16);
H_2_6_a_ts =kk(17);
H_2_7_a_ts =kk(18);
H_2_8_a_ts =kk(19);
H_2_9_a_ts =kk(20);
H_2_10_a_ts =kk(21);
H_3_1_a_ts =kk(22);
H_3_2_a_ts =kk(23);
H_3_3_a_ts =kk(24);
H_3_4_a_ts =kk(25);
H_3_5_a_ts =kk(26);
H_3_6_a_ts =kk(27);
H_3_7_a_ts =kk(28);
H_3_8_a_ts =kk(29);
H_3_9_a_ts =kk(30);
H_3_10_a_ts =kk(31);
H_4_1_a_ts =kk(32);
H_4_2_a_ts =kk(33);
H_4_3_a_ts =kk(34);
H_4_4_a_ts =kk(35);
H_4_5_a_ts =kk(36);
H_4_6_a_ts =kk(37);
H_4_7_a_ts =kk(38);
H_4_8_a_ts =kk(39);
H_4_9_a_ts =kk(40);
H_4_10_a_ts =kk(41);
H_5_1_a_ts =kk(42);
H_5_2_a_ts =kk(43);
H_5_3_a_ts =kk(44);
H_5_4_a_ts =kk(45);
H_5_5_a_ts =kk(46);
H_5_6_a_ts =kk(47);
H_5_7_a_ts =kk(48);
H_5_8_a_ts =kk(49);
H_5_9_a_ts =kk(50);
H_5_10_a_ts =kk(51);
H_6_1_a_ts =kk(52);
H_6_2_a_ts =kk(53);
H_6_3_a_ts =kk(54);
H_6_4_a_ts =kk(55);
H_6_5_a_ts =kk(56);
H_6_6_a_ts =kk(57);
H_6_7_a_ts =kk(58);
H_6_8_a_ts =kk(59);
H_6_9_a_ts =kk(60);
H_6_10_a_ts =kk(61);
H_7_1_a_ts =kk(62);
H_7_2_a_ts =kk(63);
H_7_3_a_ts =kk(64);
H_7_4_a_ts =kk(65);
H_7_5_a_ts =kk(66);
H_7_6_a_ts =kk(67);
H_7_7_a_ts =kk(68);
H_7_8_a_ts =kk(69);
H_7_9_a_ts =kk(70);
H_7_10_a_ts =kk(71);
H_8_1_a_ts =kk(72);
H_8_2_a_ts =kk(73);
H_8_3_a_ts =kk(74);
H_8_4_a_ts =kk(75);
H_8_5_a_ts =kk(76);
H_8_6_a_ts =kk(77);
H_8_7_a_ts =kk(78);
H_8_8_a_ts =kk(79);
H_8_9_a_ts =kk(80);
H_8_10_a_ts =kk(81);
H_9_1_a_ts =kk(82);
H_9_2_a_ts =kk(83);
H_9_3_a_ts =kk(84);
H_9_4_a_ts =kk(85);
H_9_5_a_ts =kk(86);
H_9_6_a_ts =kk(87);
H_9_7_a_ts =kk(88);
H_9_8_a_ts =kk(89);
H_9_9_a_ts =kk(90);
H_9_10_a_ts =kk(91);
H_10_1_a_ts =kk(92);
H_10_2_a_ts =kk(93);
H_10_3_a_ts =kk(94);
H_10_4_a_ts =kk(95);
H_10_5_a_ts =kk(96);
H_10_6_a_ts =kk(97);
H_10_7_a_ts =kk(98);
H_10_8_a_ts =kk(99);
H_10_9_a_ts =kk(100);
H_10_10_a_ts =kk(101);











@#line "SS_MSMod_10S_1C.mod" 228

I_a_ts = delta*K_a_ts;
C_a_ts = Y_VA_a_ts - I_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_1_a_ts = Psi_con_1_a*C_a_ts;
I_1_a_ts = Psi_inv_1_a*I_a_ts;


Y_1_a_ts = (C_1_a_ts+I_1_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_1_a_ts = carb_int_1_a*Y_1_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_2_a_ts = Psi_con_2_a*C_a_ts;
I_2_a_ts = Psi_inv_2_a*I_a_ts;


Y_2_a_ts = (C_2_a_ts+I_2_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_2_a_ts = carb_int_2_a*Y_2_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_3_a_ts = Psi_con_3_a*C_a_ts;
I_3_a_ts = Psi_inv_3_a*I_a_ts;


Y_3_a_ts = (C_3_a_ts+I_3_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_3_a_ts = carb_int_3_a*Y_3_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_4_a_ts = Psi_con_4_a*C_a_ts;
I_4_a_ts = Psi_inv_4_a*I_a_ts;


Y_4_a_ts = (C_4_a_ts+I_4_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_4_a_ts = carb_int_4_a*Y_4_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_5_a_ts = Psi_con_5_a*C_a_ts;
I_5_a_ts = Psi_inv_5_a*I_a_ts;


Y_5_a_ts = (C_5_a_ts+I_5_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_5_a_ts = carb_int_5_a*Y_5_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_6_a_ts = Psi_con_6_a*C_a_ts;
I_6_a_ts = Psi_inv_6_a*I_a_ts;


Y_6_a_ts = (C_6_a_ts+I_6_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_6_a_ts = carb_int_6_a*Y_6_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_7_a_ts = Psi_con_7_a*C_a_ts;
I_7_a_ts = Psi_inv_7_a*I_a_ts;


Y_7_a_ts = (C_7_a_ts+I_7_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_7_a_ts = carb_int_7_a*Y_7_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_8_a_ts = Psi_con_8_a*C_a_ts;
I_8_a_ts = Psi_inv_8_a*I_a_ts;


Y_8_a_ts = (C_8_a_ts+I_8_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_8_a_ts = carb_int_8_a*Y_8_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_9_a_ts = Psi_con_9_a*C_a_ts;
I_9_a_ts = Psi_inv_9_a*I_a_ts;


Y_9_a_ts = (C_9_a_ts+I_9_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_9_a_ts = carb_int_9_a*Y_9_a_ts;


@#line "SS_MSMod_10S_1C.mod" 233

C_10_a_ts = Psi_con_10_a*C_a_ts;
I_10_a_ts = Psi_inv_10_a*I_a_ts;


Y_10_a_ts = (C_10_a_ts+I_10_a_ts + ( 

@#line "SS_MSMod_10S_1C.mod" 240
+H_1_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_2_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_3_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_4_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_5_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_6_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_7_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_8_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_9_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 240
+H_10_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 242
)); 


ZZ_10_a_ts = carb_int_10_a*Y_10_a_ts;


@#line "SS_MSMod_10S_1C.mod" 248

@#line "SS_MSMod_10S_1C.mod" 249



@#line "SS_MSMod_10S_1C.mod" 252
ZZ_a_ts =(

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 254
+ ZZ_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 256

@#line "SS_MSMod_10S_1C.mod" 257
);


EM_ts = (

@#line "SS_MSMod_10S_1C.mod" 262

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 263
+ ZZ_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 265

@#line "SS_MSMod_10S_1C.mod" 266
)/rho_EM;


@#line "SS_MSMod_10S_1C.mod" 269

@#line "SS_MSMod_10S_1C.mod" 270

gama0_1_a =  Pen_1_a_ts - gama1_1_a*EM_ts - gama2_1_a*EM_ts^2;
   
K_1_a_ts = omega_K_tild_1_a*K_a_ts;
rk_1_a_ts = alphaH_1_a*(1-alphaN_1_a)*mc_1_a_ts*Y_1_a_ts/K_1_a_ts;
omega_K_1_a = omega_K_tild_1_a *(rk_1_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_1_a_ts = (1-alphaH_1_a)*mc_1_a_ts*Y_1_a_ts/PH_1_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_2_a =  Pen_2_a_ts - gama1_2_a*EM_ts - gama2_2_a*EM_ts^2;
   
K_2_a_ts = omega_K_tild_2_a*K_a_ts;
rk_2_a_ts = alphaH_2_a*(1-alphaN_2_a)*mc_2_a_ts*Y_2_a_ts/K_2_a_ts;
omega_K_2_a = omega_K_tild_2_a *(rk_2_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_2_a_ts = (1-alphaH_2_a)*mc_2_a_ts*Y_2_a_ts/PH_2_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_3_a =  Pen_3_a_ts - gama1_3_a*EM_ts - gama2_3_a*EM_ts^2;
   
K_3_a_ts = omega_K_tild_3_a*K_a_ts;
rk_3_a_ts = alphaH_3_a*(1-alphaN_3_a)*mc_3_a_ts*Y_3_a_ts/K_3_a_ts;
omega_K_3_a = omega_K_tild_3_a *(rk_3_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_3_a_ts = (1-alphaH_3_a)*mc_3_a_ts*Y_3_a_ts/PH_3_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_4_a =  Pen_4_a_ts - gama1_4_a*EM_ts - gama2_4_a*EM_ts^2;
   
K_4_a_ts = omega_K_tild_4_a*K_a_ts;
rk_4_a_ts = alphaH_4_a*(1-alphaN_4_a)*mc_4_a_ts*Y_4_a_ts/K_4_a_ts;
omega_K_4_a = omega_K_tild_4_a *(rk_4_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_4_a_ts = (1-alphaH_4_a)*mc_4_a_ts*Y_4_a_ts/PH_4_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_5_a =  Pen_5_a_ts - gama1_5_a*EM_ts - gama2_5_a*EM_ts^2;
   
K_5_a_ts = omega_K_tild_5_a*K_a_ts;
rk_5_a_ts = alphaH_5_a*(1-alphaN_5_a)*mc_5_a_ts*Y_5_a_ts/K_5_a_ts;
omega_K_5_a = omega_K_tild_5_a *(rk_5_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_5_a_ts = (1-alphaH_5_a)*mc_5_a_ts*Y_5_a_ts/PH_5_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_6_a =  Pen_6_a_ts - gama1_6_a*EM_ts - gama2_6_a*EM_ts^2;
   
K_6_a_ts = omega_K_tild_6_a*K_a_ts;
rk_6_a_ts = alphaH_6_a*(1-alphaN_6_a)*mc_6_a_ts*Y_6_a_ts/K_6_a_ts;
omega_K_6_a = omega_K_tild_6_a *(rk_6_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_6_a_ts = (1-alphaH_6_a)*mc_6_a_ts*Y_6_a_ts/PH_6_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_7_a =  Pen_7_a_ts - gama1_7_a*EM_ts - gama2_7_a*EM_ts^2;
   
K_7_a_ts = omega_K_tild_7_a*K_a_ts;
rk_7_a_ts = alphaH_7_a*(1-alphaN_7_a)*mc_7_a_ts*Y_7_a_ts/K_7_a_ts;
omega_K_7_a = omega_K_tild_7_a *(rk_7_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_7_a_ts = (1-alphaH_7_a)*mc_7_a_ts*Y_7_a_ts/PH_7_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_8_a =  Pen_8_a_ts - gama1_8_a*EM_ts - gama2_8_a*EM_ts^2;
   
K_8_a_ts = omega_K_tild_8_a*K_a_ts;
rk_8_a_ts = alphaH_8_a*(1-alphaN_8_a)*mc_8_a_ts*Y_8_a_ts/K_8_a_ts;
omega_K_8_a = omega_K_tild_8_a *(rk_8_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_8_a_ts = (1-alphaH_8_a)*mc_8_a_ts*Y_8_a_ts/PH_8_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_9_a =  Pen_9_a_ts - gama1_9_a*EM_ts - gama2_9_a*EM_ts^2;
   
K_9_a_ts = omega_K_tild_9_a*K_a_ts;
rk_9_a_ts = alphaH_9_a*(1-alphaN_9_a)*mc_9_a_ts*Y_9_a_ts/K_9_a_ts;
omega_K_9_a = omega_K_tild_9_a *(rk_9_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_9_a_ts = (1-alphaH_9_a)*mc_9_a_ts*Y_9_a_ts/PH_9_a_ts;


@#line "SS_MSMod_10S_1C.mod" 270

gama0_10_a =  Pen_10_a_ts - gama1_10_a*EM_ts - gama2_10_a*EM_ts^2;
   
K_10_a_ts = omega_K_tild_10_a*K_a_ts;
rk_10_a_ts = alphaH_10_a*(1-alphaN_10_a)*mc_10_a_ts*Y_10_a_ts/K_10_a_ts;
omega_K_10_a = omega_K_tild_10_a *(rk_10_a_ts/rk_a_ts)^(1/(1-upsi_K_a));                                    


H_10_a_ts = (1-alphaH_10_a)*mc_10_a_ts*Y_10_a_ts/PH_10_a_ts;


@#line "SS_MSMod_10S_1C.mod" 281

w_a_ts = (

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_1_a*alphaN_1_a*mc_1_a_ts*Y_1_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_2_a*alphaN_2_a*mc_2_a_ts*Y_2_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_3_a*alphaN_3_a*mc_3_a_ts*Y_3_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_4_a*alphaN_4_a*mc_4_a_ts*Y_4_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_5_a*alphaN_5_a*mc_5_a_ts*Y_5_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_6_a*alphaN_6_a*mc_6_a_ts*Y_6_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_7_a*alphaN_7_a*mc_7_a_ts*Y_7_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_8_a*alphaN_8_a*mc_8_a_ts*Y_8_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_9_a*alphaN_9_a*mc_9_a_ts*Y_9_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 284
+alphaH_10_a*alphaN_10_a*mc_10_a_ts*Y_10_a_ts/N_a_ts

@#line "SS_MSMod_10S_1C.mod" 286
);


@#line "SS_MSMod_10S_1C.mod" 289
N_1_a_ts = omega_N_tild_1_a*N_a_ts;
w_1_a_ts = alphaH_1_a*alphaN_1_a*mc_1_a_ts*Y_1_a_ts/N_1_a_ts;
omega_N_1_a = omega_N_tild_1_a *(w_1_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_1_a_ts   = Y_1_a_ts/((1-Pen_1_a_ts)*(N_1_a_ts^alphaN_1_a*K_1_a_ts^(1-alphaN_1_a))^alphaH_1_a*H_1_a_ts^(1-alphaH_1_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_2_a_ts = omega_N_tild_2_a*N_a_ts;
w_2_a_ts = alphaH_2_a*alphaN_2_a*mc_2_a_ts*Y_2_a_ts/N_2_a_ts;
omega_N_2_a = omega_N_tild_2_a *(w_2_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_2_a_ts   = Y_2_a_ts/((1-Pen_2_a_ts)*(N_2_a_ts^alphaN_2_a*K_2_a_ts^(1-alphaN_2_a))^alphaH_2_a*H_2_a_ts^(1-alphaH_2_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_3_a_ts = omega_N_tild_3_a*N_a_ts;
w_3_a_ts = alphaH_3_a*alphaN_3_a*mc_3_a_ts*Y_3_a_ts/N_3_a_ts;
omega_N_3_a = omega_N_tild_3_a *(w_3_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_3_a_ts   = Y_3_a_ts/((1-Pen_3_a_ts)*(N_3_a_ts^alphaN_3_a*K_3_a_ts^(1-alphaN_3_a))^alphaH_3_a*H_3_a_ts^(1-alphaH_3_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_4_a_ts = omega_N_tild_4_a*N_a_ts;
w_4_a_ts = alphaH_4_a*alphaN_4_a*mc_4_a_ts*Y_4_a_ts/N_4_a_ts;
omega_N_4_a = omega_N_tild_4_a *(w_4_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_4_a_ts   = Y_4_a_ts/((1-Pen_4_a_ts)*(N_4_a_ts^alphaN_4_a*K_4_a_ts^(1-alphaN_4_a))^alphaH_4_a*H_4_a_ts^(1-alphaH_4_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_5_a_ts = omega_N_tild_5_a*N_a_ts;
w_5_a_ts = alphaH_5_a*alphaN_5_a*mc_5_a_ts*Y_5_a_ts/N_5_a_ts;
omega_N_5_a = omega_N_tild_5_a *(w_5_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_5_a_ts   = Y_5_a_ts/((1-Pen_5_a_ts)*(N_5_a_ts^alphaN_5_a*K_5_a_ts^(1-alphaN_5_a))^alphaH_5_a*H_5_a_ts^(1-alphaH_5_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_6_a_ts = omega_N_tild_6_a*N_a_ts;
w_6_a_ts = alphaH_6_a*alphaN_6_a*mc_6_a_ts*Y_6_a_ts/N_6_a_ts;
omega_N_6_a = omega_N_tild_6_a *(w_6_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_6_a_ts   = Y_6_a_ts/((1-Pen_6_a_ts)*(N_6_a_ts^alphaN_6_a*K_6_a_ts^(1-alphaN_6_a))^alphaH_6_a*H_6_a_ts^(1-alphaH_6_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_7_a_ts = omega_N_tild_7_a*N_a_ts;
w_7_a_ts = alphaH_7_a*alphaN_7_a*mc_7_a_ts*Y_7_a_ts/N_7_a_ts;
omega_N_7_a = omega_N_tild_7_a *(w_7_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_7_a_ts   = Y_7_a_ts/((1-Pen_7_a_ts)*(N_7_a_ts^alphaN_7_a*K_7_a_ts^(1-alphaN_7_a))^alphaH_7_a*H_7_a_ts^(1-alphaH_7_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_8_a_ts = omega_N_tild_8_a*N_a_ts;
w_8_a_ts = alphaH_8_a*alphaN_8_a*mc_8_a_ts*Y_8_a_ts/N_8_a_ts;
omega_N_8_a = omega_N_tild_8_a *(w_8_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_8_a_ts   = Y_8_a_ts/((1-Pen_8_a_ts)*(N_8_a_ts^alphaN_8_a*K_8_a_ts^(1-alphaN_8_a))^alphaH_8_a*H_8_a_ts^(1-alphaH_8_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_9_a_ts = omega_N_tild_9_a*N_a_ts;
w_9_a_ts = alphaH_9_a*alphaN_9_a*mc_9_a_ts*Y_9_a_ts/N_9_a_ts;
omega_N_9_a = omega_N_tild_9_a *(w_9_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_9_a_ts   = Y_9_a_ts/((1-Pen_9_a_ts)*(N_9_a_ts^alphaN_9_a*K_9_a_ts^(1-alphaN_9_a))^alphaH_9_a*H_9_a_ts^(1-alphaH_9_a));

@#line "SS_MSMod_10S_1C.mod" 289
N_10_a_ts = omega_N_tild_10_a*N_a_ts;
w_10_a_ts = alphaH_10_a*alphaN_10_a*mc_10_a_ts*Y_10_a_ts/N_10_a_ts;
omega_N_10_a = omega_N_tild_10_a *(w_10_a_ts/w_a_ts)^(1/(1-upsi_N_a));                                          

epsi_10_a_ts   = Y_10_a_ts/((1-Pen_10_a_ts)*(N_10_a_ts^alphaN_10_a*K_10_a_ts^(1-alphaN_10_a))^alphaH_10_a*H_10_a_ts^(1-alphaH_10_a));

@#line "SS_MSMod_10S_1C.mod" 295

lambda_a_ts = C_a_ts^(-sig);

kappaN_a    = lambda_a_ts*w_a_ts/(N_a_ts^lab_a);


@#line "SS_MSMod_10S_1C.mod" 301
Y_a_ts =(

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_1_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_2_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_3_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_4_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_5_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_6_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_7_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_8_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_9_a_ts

@#line "SS_MSMod_10S_1C.mod" 303
+ Y_10_a_ts

@#line "SS_MSMod_10S_1C.mod" 305

@#line "SS_MSMod_10S_1C.mod" 306
);


@#line "SS_MSMod_10S_1C.mod" 309

























































@#line "MS_1C_Mod_simul.mod" 74


@#line "Equations_10S_1C.mod" 1
model;

// ######################################################################### 
// Climate variables
// #########################################################################


@#line "Equations_10S_1C.mod" 8
P_EM_a_t = P_EM_a_ts + shock_P_EM_a_t; //Law of motion for carbon price 
log(epsi_a_t/epsi_a_ts) = rho_eps_a * log(epsi_a_t(-1)/epsi_a_ts) + shock_epsi_a_t; //Law of motion for aggregate TFP

@#line "Equations_10S_1C.mod" 11

EM_t = (1-rho_EM)*EM_t(-1) + (

@#line "Equations_10S_1C.mod" 14

@#line "Equations_10S_1C.mod" 15
+ ZZ_1_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_2_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_3_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_4_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_5_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_6_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_7_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_8_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_9_a_t

@#line "Equations_10S_1C.mod" 15
+ ZZ_10_a_t

@#line "Equations_10S_1C.mod" 17

@#line "Equations_10S_1C.mod" 18
);                                                                          //Law of motion for emissions concentration


@#line "Equations_10S_1C.mod" 21

@#line "Equations_10S_1C.mod" 22
Pen_1_a_t = gama0_1_a + gama1_1_a*EM_t + gama2_1_a*EM_t^2;  //Damage function
ZZ_1_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_1_a)*Y_1_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_2_a_t = gama0_2_a + gama1_2_a*EM_t + gama2_2_a*EM_t^2;  //Damage function
ZZ_2_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_2_a)*Y_2_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_3_a_t = gama0_3_a + gama1_3_a*EM_t + gama2_3_a*EM_t^2;  //Damage function
ZZ_3_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_3_a)*Y_3_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_4_a_t = gama0_4_a + gama1_4_a*EM_t + gama2_4_a*EM_t^2;  //Damage function
ZZ_4_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_4_a)*Y_4_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_5_a_t = gama0_5_a + gama1_5_a*EM_t + gama2_5_a*EM_t^2;  //Damage function
ZZ_5_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_5_a)*Y_5_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_6_a_t = gama0_6_a + gama1_6_a*EM_t + gama2_6_a*EM_t^2;  //Damage function
ZZ_6_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_6_a)*Y_6_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_7_a_t = gama0_7_a + gama1_7_a*EM_t + gama2_7_a*EM_t^2;  //Damage function
ZZ_7_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_7_a)*Y_7_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_8_a_t = gama0_8_a + gama1_8_a*EM_t + gama2_8_a*EM_t^2;  //Damage function
ZZ_8_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_8_a)*Y_8_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_9_a_t = gama0_9_a + gama1_9_a*EM_t + gama2_9_a*EM_t^2;  //Damage function
ZZ_9_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_9_a)*Y_9_a_t; //Emissions

@#line "Equations_10S_1C.mod" 22
Pen_10_a_t = gama0_10_a + gama1_10_a*EM_t + gama2_10_a*EM_t^2;  //Damage function
ZZ_10_a_t = ((1+shock_epsi_carb_int_a_t)*carb_int_10_a)*Y_10_a_t; //Emissions

@#line "Equations_10S_1C.mod" 25

@#line "Equations_10S_1C.mod" 26

                                                                            //Aggregate sectoral emissions in a given country

@#line "Equations_10S_1C.mod" 29
ZZ_a_t =(

@#line "Equations_10S_1C.mod" 31
+ ZZ_1_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_2_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_3_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_4_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_5_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_6_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_7_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_8_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_9_a_t

@#line "Equations_10S_1C.mod" 31
+ ZZ_10_a_t

@#line "Equations_10S_1C.mod" 33

@#line "Equations_10S_1C.mod" 34
);

// ######################################################################### 
// Domestic aggregates
// #########################################################################


@#line "Equations_10S_1C.mod" 41
log(R_a_t/R_a_ts) = 0.8^4*log(R_a_t(-1)/R_a_ts) + 1.5*(1-0.8^4)*log(pi_cpi_a_t(-1));        //Modified Taylor-rule

K_a_t = (1-delta)*K_a_t(-1) + I_a_t;                                                            //Law of motion for capital

lambda_a_t = C_a_t^(-sig);                                                        //FOC wrt consumption

1 = betta*lambda_a_t(+1)/lambda_a_t*R_a_t/pi_cpi_a_t(+1);                                   //HH FOC wrt bonds

1 = betta*lambda_a_t(+1)/lambda_a_t*(rk_a_t(+1)+(1-delta)*PI_a_t(+1))/PI_a_t;                        //No arbitrage cond. plus FOC wrt investment/capital

lambda_a_t*w_a_t = kappaN_a*N_a_t^lab_a;                              //HH FOC wrt labor

1 = (

@#line "Equations_10S_1C.mod" 55
+ Psi_con_1_a*P_1_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_2_a*P_2_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_3_a*P_3_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_4_a*P_4_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_5_a*P_5_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_6_a*P_6_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_7_a*P_7_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_8_a*P_8_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_9_a*P_9_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 55
+ Psi_con_10_a*P_10_a_t^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 57
)^(-(1-sigc_a)/sigc_a);                                             //Price index derived from opt. problem of cons.-bundler 

pi_cpi_a_t = (

@#line "Equations_10S_1C.mod" 61
+ Psi_con_1_a*(pi_ppi_1_a_t*P_1_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_2_a*(pi_ppi_2_a_t*P_2_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_3_a*(pi_ppi_3_a_t*P_3_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_4_a*(pi_ppi_4_a_t*P_4_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_5_a*(pi_ppi_5_a_t*P_5_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_6_a*(pi_ppi_6_a_t*P_6_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_7_a*(pi_ppi_7_a_t*P_7_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_8_a*(pi_ppi_8_a_t*P_8_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_9_a*(pi_ppi_9_a_t*P_9_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 61
+ Psi_con_10_a*(pi_ppi_10_a_t*P_10_a_t(-1))^(-sigc_a/(1-sigc_a))

@#line "Equations_10S_1C.mod" 63
)^(-(1-sigc_a)/sigc_a);                                             //CPI-inflation 

PI_a_t = (

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_1_a*P_1_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_2_a*P_2_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_3_a*P_3_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_4_a*P_4_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_5_a*P_5_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_6_a*P_6_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_7_a*P_7_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_8_a*P_8_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_9_a*P_9_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 67
+ Psi_inv_10_a*P_10_a_t^(-sigi_a/(1-sigi_a))

@#line "Equations_10S_1C.mod" 69
)^(-(1-sigi_a)/sigi_a);                                             //Price index derived from opt. problem of inv.-bundler 

w_a_t = (

@#line "Equations_10S_1C.mod" 73
+  omega_N_1_a*w_1_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_2_a*w_2_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_3_a*w_3_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_4_a*w_4_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_5_a*w_5_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_6_a*w_6_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_7_a*w_7_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_8_a*w_8_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_9_a*w_9_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 73
+  omega_N_10_a*w_10_a_t^(-upsi_N_a/(1-upsi_N_a))

@#line "Equations_10S_1C.mod" 75
)^(-(1-upsi_N_a)/upsi_N_a);                                         //Wage index derived from opt. problem of labor-bundler

rk_a_t = (

@#line "Equations_10S_1C.mod" 79
+  omega_K_1_a*rk_1_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_2_a*rk_2_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_3_a*rk_3_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_4_a*rk_4_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_5_a*rk_5_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_6_a*rk_6_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_7_a*rk_7_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_8_a*rk_8_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_9_a*rk_9_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 79
+  omega_K_10_a*rk_10_a_t^(-upsi_K_a/(1-upsi_K_a))

@#line "Equations_10S_1C.mod" 81
)^(-(1-upsi_K_a)/upsi_K_a);                                         //Rental rate index derived from opt. problem of capital-bundler

Y_VA_a_t = C_a_t + PI_a_t*I_a_t;

// ######################################################################### 
// Consumption and investmend demand for different goods, relative prices
// ######################################################################### 

@#line "Equations_10S_1C.mod" 89
C_1_a_t = Psi_con_1_a*(1/P_1_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_1_a_t = Psi_inv_1_a*(PI_a_t/P_1_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_1_a_t = omega_N_1_a*(w_a_t/w_1_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_1_a_t = omega_K_1_a*(rk_a_t(+1)/rk_1_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_1_a_t*Y_1_a_t  = P_1_a_t*C_1_a_t + P_1_a_t*I_1_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_1_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_2_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_3_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_4_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_5_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_6_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_7_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_8_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_9_1_a_t

@#line "Equations_10S_1C.mod" 100
+P_1_a_t*H_10_1_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_1_a_t = epsi_a_t * epsi_1_a_t*(1-Pen_1_a_t)*(N_1_a_t^alphaN_1_a*K_1_a_t(-1)^(1-alphaN_1_a))^alphaH_1_a*H_1_a_t^(1-alphaH_1_a); //Production technology of perfectly competitive firm

EM_cost_1_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_1_a); //Emissions costs

mc_tild_1_a_t = EM_cost_1_a_t + mc_1_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_1_a_t = mc_tild_1_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_1_a_t  = alphaH_1_a*alphaN_1_a*mc_1_a_t*Y_1_a_t/N_1_a_t;             //FOC firm cost minimization -> labor

rk_1_a_t = alphaH_1_a*(1-alphaN_1_a)*mc_1_a_t*Y_1_a_t/K_1_a_t(-1);     //FOC firm cost minimization -> capital

PH_1_a_t = (1-alphaH_1_a)*mc_1_a_t*Y_1_a_t/H_1_a_t;  //FOC firm cost minimization -> intermediates

PH_1_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_1_1_a*P_1_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_2_a*P_2_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_3_a*P_3_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_4_a*P_4_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_5_a*P_5_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_6_a*P_6_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_7_a*P_7_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_8_a*P_8_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_9_a*P_9_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_1_10_a*P_10_a_t^(-sigh_1_a/(1-sigh_1_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_1_a)/sigh_1_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_1_1_a_t = Psi_1_1_a*(PH_1_a_t/P_1_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_2_a_t = Psi_1_2_a*(PH_1_a_t/P_2_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_3_a_t = Psi_1_3_a*(PH_1_a_t/P_3_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_4_a_t = Psi_1_4_a*(PH_1_a_t/P_4_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_5_a_t = Psi_1_5_a*(PH_1_a_t/P_5_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_6_a_t = Psi_1_6_a*(PH_1_a_t/P_6_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_7_a_t = Psi_1_7_a*(PH_1_a_t/P_7_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_8_a_t = Psi_1_8_a*(PH_1_a_t/P_8_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_9_a_t = Psi_1_9_a*(PH_1_a_t/P_9_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_1_10_a_t = Psi_1_10_a*(PH_1_a_t/P_10_a_t)^(1/(1-sigh_1_a))*H_1_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_1_a_t/epsi_1_a_ts) = rho_eps_a*log(epsi_1_a_t(-1)/epsi_1_a_ts) + shock_epsi_1_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_2_a_t = Psi_con_2_a*(1/P_2_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_2_a_t = Psi_inv_2_a*(PI_a_t/P_2_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_2_a_t = omega_N_2_a*(w_a_t/w_2_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_2_a_t = omega_K_2_a*(rk_a_t(+1)/rk_2_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_2_a_t*Y_2_a_t  = P_2_a_t*C_2_a_t + P_2_a_t*I_2_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_1_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_2_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_3_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_4_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_5_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_6_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_7_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_8_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_9_2_a_t

@#line "Equations_10S_1C.mod" 100
+P_2_a_t*H_10_2_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_2_a_t = epsi_a_t * epsi_2_a_t*(1-Pen_2_a_t)*(N_2_a_t^alphaN_2_a*K_2_a_t(-1)^(1-alphaN_2_a))^alphaH_2_a*H_2_a_t^(1-alphaH_2_a); //Production technology of perfectly competitive firm

EM_cost_2_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_2_a); //Emissions costs

mc_tild_2_a_t = EM_cost_2_a_t + mc_2_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_2_a_t = mc_tild_2_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_2_a_t  = alphaH_2_a*alphaN_2_a*mc_2_a_t*Y_2_a_t/N_2_a_t;             //FOC firm cost minimization -> labor

rk_2_a_t = alphaH_2_a*(1-alphaN_2_a)*mc_2_a_t*Y_2_a_t/K_2_a_t(-1);     //FOC firm cost minimization -> capital

PH_2_a_t = (1-alphaH_2_a)*mc_2_a_t*Y_2_a_t/H_2_a_t;  //FOC firm cost minimization -> intermediates

PH_2_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_2_1_a*P_1_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_2_a*P_2_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_3_a*P_3_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_4_a*P_4_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_5_a*P_5_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_6_a*P_6_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_7_a*P_7_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_8_a*P_8_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_9_a*P_9_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_2_10_a*P_10_a_t^(-sigh_2_a/(1-sigh_2_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_2_a)/sigh_2_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_2_1_a_t = Psi_2_1_a*(PH_2_a_t/P_1_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_2_a_t = Psi_2_2_a*(PH_2_a_t/P_2_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_3_a_t = Psi_2_3_a*(PH_2_a_t/P_3_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_4_a_t = Psi_2_4_a*(PH_2_a_t/P_4_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_5_a_t = Psi_2_5_a*(PH_2_a_t/P_5_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_6_a_t = Psi_2_6_a*(PH_2_a_t/P_6_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_7_a_t = Psi_2_7_a*(PH_2_a_t/P_7_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_8_a_t = Psi_2_8_a*(PH_2_a_t/P_8_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_9_a_t = Psi_2_9_a*(PH_2_a_t/P_9_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_2_10_a_t = Psi_2_10_a*(PH_2_a_t/P_10_a_t)^(1/(1-sigh_2_a))*H_2_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_2_a_t/epsi_2_a_ts) = rho_eps_a*log(epsi_2_a_t(-1)/epsi_2_a_ts) + shock_epsi_2_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_3_a_t = Psi_con_3_a*(1/P_3_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_3_a_t = Psi_inv_3_a*(PI_a_t/P_3_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_3_a_t = omega_N_3_a*(w_a_t/w_3_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_3_a_t = omega_K_3_a*(rk_a_t(+1)/rk_3_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_3_a_t*Y_3_a_t  = P_3_a_t*C_3_a_t + P_3_a_t*I_3_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_1_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_2_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_3_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_4_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_5_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_6_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_7_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_8_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_9_3_a_t

@#line "Equations_10S_1C.mod" 100
+P_3_a_t*H_10_3_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_3_a_t = epsi_a_t * epsi_3_a_t*(1-Pen_3_a_t)*(N_3_a_t^alphaN_3_a*K_3_a_t(-1)^(1-alphaN_3_a))^alphaH_3_a*H_3_a_t^(1-alphaH_3_a); //Production technology of perfectly competitive firm

EM_cost_3_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_3_a); //Emissions costs

mc_tild_3_a_t = EM_cost_3_a_t + mc_3_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_3_a_t = mc_tild_3_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_3_a_t  = alphaH_3_a*alphaN_3_a*mc_3_a_t*Y_3_a_t/N_3_a_t;             //FOC firm cost minimization -> labor

rk_3_a_t = alphaH_3_a*(1-alphaN_3_a)*mc_3_a_t*Y_3_a_t/K_3_a_t(-1);     //FOC firm cost minimization -> capital

PH_3_a_t = (1-alphaH_3_a)*mc_3_a_t*Y_3_a_t/H_3_a_t;  //FOC firm cost minimization -> intermediates

PH_3_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_3_1_a*P_1_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_2_a*P_2_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_3_a*P_3_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_4_a*P_4_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_5_a*P_5_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_6_a*P_6_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_7_a*P_7_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_8_a*P_8_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_9_a*P_9_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_3_10_a*P_10_a_t^(-sigh_3_a/(1-sigh_3_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_3_a)/sigh_3_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_3_1_a_t = Psi_3_1_a*(PH_3_a_t/P_1_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_2_a_t = Psi_3_2_a*(PH_3_a_t/P_2_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_3_a_t = Psi_3_3_a*(PH_3_a_t/P_3_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_4_a_t = Psi_3_4_a*(PH_3_a_t/P_4_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_5_a_t = Psi_3_5_a*(PH_3_a_t/P_5_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_6_a_t = Psi_3_6_a*(PH_3_a_t/P_6_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_7_a_t = Psi_3_7_a*(PH_3_a_t/P_7_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_8_a_t = Psi_3_8_a*(PH_3_a_t/P_8_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_9_a_t = Psi_3_9_a*(PH_3_a_t/P_9_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_3_10_a_t = Psi_3_10_a*(PH_3_a_t/P_10_a_t)^(1/(1-sigh_3_a))*H_3_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_3_a_t/epsi_3_a_ts) = rho_eps_a*log(epsi_3_a_t(-1)/epsi_3_a_ts) + shock_epsi_3_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_4_a_t = Psi_con_4_a*(1/P_4_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_4_a_t = Psi_inv_4_a*(PI_a_t/P_4_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_4_a_t = omega_N_4_a*(w_a_t/w_4_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_4_a_t = omega_K_4_a*(rk_a_t(+1)/rk_4_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_4_a_t*Y_4_a_t  = P_4_a_t*C_4_a_t + P_4_a_t*I_4_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_1_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_2_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_3_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_4_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_5_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_6_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_7_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_8_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_9_4_a_t

@#line "Equations_10S_1C.mod" 100
+P_4_a_t*H_10_4_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_4_a_t = epsi_a_t * epsi_4_a_t*(1-Pen_4_a_t)*(N_4_a_t^alphaN_4_a*K_4_a_t(-1)^(1-alphaN_4_a))^alphaH_4_a*H_4_a_t^(1-alphaH_4_a); //Production technology of perfectly competitive firm

EM_cost_4_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_4_a); //Emissions costs

mc_tild_4_a_t = EM_cost_4_a_t + mc_4_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_4_a_t = mc_tild_4_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_4_a_t  = alphaH_4_a*alphaN_4_a*mc_4_a_t*Y_4_a_t/N_4_a_t;             //FOC firm cost minimization -> labor

rk_4_a_t = alphaH_4_a*(1-alphaN_4_a)*mc_4_a_t*Y_4_a_t/K_4_a_t(-1);     //FOC firm cost minimization -> capital

PH_4_a_t = (1-alphaH_4_a)*mc_4_a_t*Y_4_a_t/H_4_a_t;  //FOC firm cost minimization -> intermediates

PH_4_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_4_1_a*P_1_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_2_a*P_2_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_3_a*P_3_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_4_a*P_4_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_5_a*P_5_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_6_a*P_6_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_7_a*P_7_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_8_a*P_8_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_9_a*P_9_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_4_10_a*P_10_a_t^(-sigh_4_a/(1-sigh_4_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_4_a)/sigh_4_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_4_1_a_t = Psi_4_1_a*(PH_4_a_t/P_1_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_2_a_t = Psi_4_2_a*(PH_4_a_t/P_2_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_3_a_t = Psi_4_3_a*(PH_4_a_t/P_3_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_4_a_t = Psi_4_4_a*(PH_4_a_t/P_4_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_5_a_t = Psi_4_5_a*(PH_4_a_t/P_5_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_6_a_t = Psi_4_6_a*(PH_4_a_t/P_6_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_7_a_t = Psi_4_7_a*(PH_4_a_t/P_7_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_8_a_t = Psi_4_8_a*(PH_4_a_t/P_8_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_9_a_t = Psi_4_9_a*(PH_4_a_t/P_9_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_4_10_a_t = Psi_4_10_a*(PH_4_a_t/P_10_a_t)^(1/(1-sigh_4_a))*H_4_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_4_a_t/epsi_4_a_ts) = rho_eps_a*log(epsi_4_a_t(-1)/epsi_4_a_ts) + shock_epsi_4_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_5_a_t = Psi_con_5_a*(1/P_5_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_5_a_t = Psi_inv_5_a*(PI_a_t/P_5_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_5_a_t = omega_N_5_a*(w_a_t/w_5_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_5_a_t = omega_K_5_a*(rk_a_t(+1)/rk_5_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_5_a_t*Y_5_a_t  = P_5_a_t*C_5_a_t + P_5_a_t*I_5_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_1_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_2_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_3_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_4_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_5_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_6_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_7_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_8_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_9_5_a_t

@#line "Equations_10S_1C.mod" 100
+P_5_a_t*H_10_5_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_5_a_t = epsi_a_t * epsi_5_a_t*(1-Pen_5_a_t)*(N_5_a_t^alphaN_5_a*K_5_a_t(-1)^(1-alphaN_5_a))^alphaH_5_a*H_5_a_t^(1-alphaH_5_a); //Production technology of perfectly competitive firm

EM_cost_5_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_5_a); //Emissions costs

mc_tild_5_a_t = EM_cost_5_a_t + mc_5_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_5_a_t = mc_tild_5_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_5_a_t  = alphaH_5_a*alphaN_5_a*mc_5_a_t*Y_5_a_t/N_5_a_t;             //FOC firm cost minimization -> labor

rk_5_a_t = alphaH_5_a*(1-alphaN_5_a)*mc_5_a_t*Y_5_a_t/K_5_a_t(-1);     //FOC firm cost minimization -> capital

PH_5_a_t = (1-alphaH_5_a)*mc_5_a_t*Y_5_a_t/H_5_a_t;  //FOC firm cost minimization -> intermediates

PH_5_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_5_1_a*P_1_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_2_a*P_2_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_3_a*P_3_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_4_a*P_4_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_5_a*P_5_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_6_a*P_6_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_7_a*P_7_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_8_a*P_8_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_9_a*P_9_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_5_10_a*P_10_a_t^(-sigh_5_a/(1-sigh_5_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_5_a)/sigh_5_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_5_1_a_t = Psi_5_1_a*(PH_5_a_t/P_1_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_2_a_t = Psi_5_2_a*(PH_5_a_t/P_2_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_3_a_t = Psi_5_3_a*(PH_5_a_t/P_3_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_4_a_t = Psi_5_4_a*(PH_5_a_t/P_4_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_5_a_t = Psi_5_5_a*(PH_5_a_t/P_5_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_6_a_t = Psi_5_6_a*(PH_5_a_t/P_6_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_7_a_t = Psi_5_7_a*(PH_5_a_t/P_7_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_8_a_t = Psi_5_8_a*(PH_5_a_t/P_8_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_9_a_t = Psi_5_9_a*(PH_5_a_t/P_9_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_5_10_a_t = Psi_5_10_a*(PH_5_a_t/P_10_a_t)^(1/(1-sigh_5_a))*H_5_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_5_a_t/epsi_5_a_ts) = rho_eps_a*log(epsi_5_a_t(-1)/epsi_5_a_ts) + shock_epsi_5_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_6_a_t = Psi_con_6_a*(1/P_6_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_6_a_t = Psi_inv_6_a*(PI_a_t/P_6_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_6_a_t = omega_N_6_a*(w_a_t/w_6_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_6_a_t = omega_K_6_a*(rk_a_t(+1)/rk_6_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_6_a_t*Y_6_a_t  = P_6_a_t*C_6_a_t + P_6_a_t*I_6_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_1_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_2_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_3_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_4_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_5_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_6_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_7_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_8_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_9_6_a_t

@#line "Equations_10S_1C.mod" 100
+P_6_a_t*H_10_6_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_6_a_t = epsi_a_t * epsi_6_a_t*(1-Pen_6_a_t)*(N_6_a_t^alphaN_6_a*K_6_a_t(-1)^(1-alphaN_6_a))^alphaH_6_a*H_6_a_t^(1-alphaH_6_a); //Production technology of perfectly competitive firm

EM_cost_6_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_6_a); //Emissions costs

mc_tild_6_a_t = EM_cost_6_a_t + mc_6_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_6_a_t = mc_tild_6_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_6_a_t  = alphaH_6_a*alphaN_6_a*mc_6_a_t*Y_6_a_t/N_6_a_t;             //FOC firm cost minimization -> labor

rk_6_a_t = alphaH_6_a*(1-alphaN_6_a)*mc_6_a_t*Y_6_a_t/K_6_a_t(-1);     //FOC firm cost minimization -> capital

PH_6_a_t = (1-alphaH_6_a)*mc_6_a_t*Y_6_a_t/H_6_a_t;  //FOC firm cost minimization -> intermediates

PH_6_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_6_1_a*P_1_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_2_a*P_2_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_3_a*P_3_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_4_a*P_4_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_5_a*P_5_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_6_a*P_6_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_7_a*P_7_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_8_a*P_8_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_9_a*P_9_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_6_10_a*P_10_a_t^(-sigh_6_a/(1-sigh_6_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_6_a)/sigh_6_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_6_1_a_t = Psi_6_1_a*(PH_6_a_t/P_1_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_2_a_t = Psi_6_2_a*(PH_6_a_t/P_2_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_3_a_t = Psi_6_3_a*(PH_6_a_t/P_3_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_4_a_t = Psi_6_4_a*(PH_6_a_t/P_4_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_5_a_t = Psi_6_5_a*(PH_6_a_t/P_5_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_6_a_t = Psi_6_6_a*(PH_6_a_t/P_6_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_7_a_t = Psi_6_7_a*(PH_6_a_t/P_7_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_8_a_t = Psi_6_8_a*(PH_6_a_t/P_8_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_9_a_t = Psi_6_9_a*(PH_6_a_t/P_9_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_6_10_a_t = Psi_6_10_a*(PH_6_a_t/P_10_a_t)^(1/(1-sigh_6_a))*H_6_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_6_a_t/epsi_6_a_ts) = rho_eps_a*log(epsi_6_a_t(-1)/epsi_6_a_ts) + shock_epsi_6_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_7_a_t = Psi_con_7_a*(1/P_7_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_7_a_t = Psi_inv_7_a*(PI_a_t/P_7_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_7_a_t = omega_N_7_a*(w_a_t/w_7_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_7_a_t = omega_K_7_a*(rk_a_t(+1)/rk_7_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_7_a_t*Y_7_a_t  = P_7_a_t*C_7_a_t + P_7_a_t*I_7_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_1_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_2_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_3_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_4_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_5_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_6_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_7_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_8_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_9_7_a_t

@#line "Equations_10S_1C.mod" 100
+P_7_a_t*H_10_7_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_7_a_t = epsi_a_t * epsi_7_a_t*(1-Pen_7_a_t)*(N_7_a_t^alphaN_7_a*K_7_a_t(-1)^(1-alphaN_7_a))^alphaH_7_a*H_7_a_t^(1-alphaH_7_a); //Production technology of perfectly competitive firm

EM_cost_7_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_7_a); //Emissions costs

mc_tild_7_a_t = EM_cost_7_a_t + mc_7_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_7_a_t = mc_tild_7_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_7_a_t  = alphaH_7_a*alphaN_7_a*mc_7_a_t*Y_7_a_t/N_7_a_t;             //FOC firm cost minimization -> labor

rk_7_a_t = alphaH_7_a*(1-alphaN_7_a)*mc_7_a_t*Y_7_a_t/K_7_a_t(-1);     //FOC firm cost minimization -> capital

PH_7_a_t = (1-alphaH_7_a)*mc_7_a_t*Y_7_a_t/H_7_a_t;  //FOC firm cost minimization -> intermediates

PH_7_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_7_1_a*P_1_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_2_a*P_2_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_3_a*P_3_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_4_a*P_4_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_5_a*P_5_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_6_a*P_6_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_7_a*P_7_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_8_a*P_8_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_9_a*P_9_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_7_10_a*P_10_a_t^(-sigh_7_a/(1-sigh_7_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_7_a)/sigh_7_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_7_1_a_t = Psi_7_1_a*(PH_7_a_t/P_1_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_2_a_t = Psi_7_2_a*(PH_7_a_t/P_2_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_3_a_t = Psi_7_3_a*(PH_7_a_t/P_3_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_4_a_t = Psi_7_4_a*(PH_7_a_t/P_4_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_5_a_t = Psi_7_5_a*(PH_7_a_t/P_5_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_6_a_t = Psi_7_6_a*(PH_7_a_t/P_6_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_7_a_t = Psi_7_7_a*(PH_7_a_t/P_7_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_8_a_t = Psi_7_8_a*(PH_7_a_t/P_8_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_9_a_t = Psi_7_9_a*(PH_7_a_t/P_9_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_7_10_a_t = Psi_7_10_a*(PH_7_a_t/P_10_a_t)^(1/(1-sigh_7_a))*H_7_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_7_a_t/epsi_7_a_ts) = rho_eps_a*log(epsi_7_a_t(-1)/epsi_7_a_ts) + shock_epsi_7_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_8_a_t = Psi_con_8_a*(1/P_8_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_8_a_t = Psi_inv_8_a*(PI_a_t/P_8_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_8_a_t = omega_N_8_a*(w_a_t/w_8_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_8_a_t = omega_K_8_a*(rk_a_t(+1)/rk_8_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_8_a_t*Y_8_a_t  = P_8_a_t*C_8_a_t + P_8_a_t*I_8_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_1_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_2_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_3_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_4_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_5_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_6_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_7_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_8_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_9_8_a_t

@#line "Equations_10S_1C.mod" 100
+P_8_a_t*H_10_8_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_8_a_t = epsi_a_t * epsi_8_a_t*(1-Pen_8_a_t)*(N_8_a_t^alphaN_8_a*K_8_a_t(-1)^(1-alphaN_8_a))^alphaH_8_a*H_8_a_t^(1-alphaH_8_a); //Production technology of perfectly competitive firm

EM_cost_8_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_8_a); //Emissions costs

mc_tild_8_a_t = EM_cost_8_a_t + mc_8_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_8_a_t = mc_tild_8_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_8_a_t  = alphaH_8_a*alphaN_8_a*mc_8_a_t*Y_8_a_t/N_8_a_t;             //FOC firm cost minimization -> labor

rk_8_a_t = alphaH_8_a*(1-alphaN_8_a)*mc_8_a_t*Y_8_a_t/K_8_a_t(-1);     //FOC firm cost minimization -> capital

PH_8_a_t = (1-alphaH_8_a)*mc_8_a_t*Y_8_a_t/H_8_a_t;  //FOC firm cost minimization -> intermediates

PH_8_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_8_1_a*P_1_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_2_a*P_2_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_3_a*P_3_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_4_a*P_4_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_5_a*P_5_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_6_a*P_6_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_7_a*P_7_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_8_a*P_8_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_9_a*P_9_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_8_10_a*P_10_a_t^(-sigh_8_a/(1-sigh_8_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_8_a)/sigh_8_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_8_1_a_t = Psi_8_1_a*(PH_8_a_t/P_1_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_2_a_t = Psi_8_2_a*(PH_8_a_t/P_2_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_3_a_t = Psi_8_3_a*(PH_8_a_t/P_3_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_4_a_t = Psi_8_4_a*(PH_8_a_t/P_4_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_5_a_t = Psi_8_5_a*(PH_8_a_t/P_5_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_6_a_t = Psi_8_6_a*(PH_8_a_t/P_6_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_7_a_t = Psi_8_7_a*(PH_8_a_t/P_7_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_8_a_t = Psi_8_8_a*(PH_8_a_t/P_8_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_9_a_t = Psi_8_9_a*(PH_8_a_t/P_9_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_8_10_a_t = Psi_8_10_a*(PH_8_a_t/P_10_a_t)^(1/(1-sigh_8_a))*H_8_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_8_a_t/epsi_8_a_ts) = rho_eps_a*log(epsi_8_a_t(-1)/epsi_8_a_ts) + shock_epsi_8_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_9_a_t = Psi_con_9_a*(1/P_9_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_9_a_t = Psi_inv_9_a*(PI_a_t/P_9_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_9_a_t = omega_N_9_a*(w_a_t/w_9_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_9_a_t = omega_K_9_a*(rk_a_t(+1)/rk_9_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_9_a_t*Y_9_a_t  = P_9_a_t*C_9_a_t + P_9_a_t*I_9_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_1_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_2_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_3_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_4_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_5_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_6_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_7_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_8_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_9_9_a_t

@#line "Equations_10S_1C.mod" 100
+P_9_a_t*H_10_9_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_9_a_t = epsi_a_t * epsi_9_a_t*(1-Pen_9_a_t)*(N_9_a_t^alphaN_9_a*K_9_a_t(-1)^(1-alphaN_9_a))^alphaH_9_a*H_9_a_t^(1-alphaH_9_a); //Production technology of perfectly competitive firm

EM_cost_9_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_9_a); //Emissions costs

mc_tild_9_a_t = EM_cost_9_a_t + mc_9_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_9_a_t = mc_tild_9_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_9_a_t  = alphaH_9_a*alphaN_9_a*mc_9_a_t*Y_9_a_t/N_9_a_t;             //FOC firm cost minimization -> labor

rk_9_a_t = alphaH_9_a*(1-alphaN_9_a)*mc_9_a_t*Y_9_a_t/K_9_a_t(-1);     //FOC firm cost minimization -> capital

PH_9_a_t = (1-alphaH_9_a)*mc_9_a_t*Y_9_a_t/H_9_a_t;  //FOC firm cost minimization -> intermediates

PH_9_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_9_1_a*P_1_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_2_a*P_2_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_3_a*P_3_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_4_a*P_4_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_5_a*P_5_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_6_a*P_6_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_7_a*P_7_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_8_a*P_8_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_9_a*P_9_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_9_10_a*P_10_a_t^(-sigh_9_a/(1-sigh_9_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_9_a)/sigh_9_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_9_1_a_t = Psi_9_1_a*(PH_9_a_t/P_1_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_2_a_t = Psi_9_2_a*(PH_9_a_t/P_2_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_3_a_t = Psi_9_3_a*(PH_9_a_t/P_3_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_4_a_t = Psi_9_4_a*(PH_9_a_t/P_4_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_5_a_t = Psi_9_5_a*(PH_9_a_t/P_5_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_6_a_t = Psi_9_6_a*(PH_9_a_t/P_6_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_7_a_t = Psi_9_7_a*(PH_9_a_t/P_7_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_8_a_t = Psi_9_8_a*(PH_9_a_t/P_8_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_9_a_t = Psi_9_9_a*(PH_9_a_t/P_9_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_9_10_a_t = Psi_9_10_a*(PH_9_a_t/P_10_a_t)^(1/(1-sigh_9_a))*H_9_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_9_a_t/epsi_9_a_ts) = rho_eps_a*log(epsi_9_a_t(-1)/epsi_9_a_ts) + shock_epsi_9_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 89
C_10_a_t = Psi_con_10_a*(1/P_10_a_t)^(1/(1-sigc_a))*C_a_t;                                                                  //Specific demand for sectoral consumption goods

I_10_a_t = Psi_inv_10_a*(PI_a_t/P_10_a_t)^(1/(1-sigi_a))*I_a_t;                                                         //Specific demand for sectoral investment goods

N_10_a_t = omega_N_10_a*(w_a_t/w_10_a_t)^(1/(1-upsi_N_a))*N_a_t;                                                        //Specific demand for labor types

K_10_a_t = omega_K_10_a*(rk_a_t(+1)/rk_10_a_t(+1))^(1/(1-upsi_K_a))*K_a_t;                                              //Specific demand for capital types   

                                                                                                                                                         //The following eqn is the sectoral market clearing condition
P_10_a_t*Y_10_a_t  = P_10_a_t*C_10_a_t + P_10_a_t*I_10_a_t + ( 

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_1_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_2_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_3_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_4_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_5_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_6_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_7_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_8_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_9_10_a_t

@#line "Equations_10S_1C.mod" 100
+P_10_a_t*H_10_10_a_t

@#line "Equations_10S_1C.mod" 102
);

Y_10_a_t = epsi_a_t * epsi_10_a_t*(1-Pen_10_a_t)*(N_10_a_t^alphaN_10_a*K_10_a_t(-1)^(1-alphaN_10_a))^alphaH_10_a*H_10_a_t^(1-alphaH_10_a); //Production technology of perfectly competitive firm

EM_cost_10_a_t = P_EM_a_t*((1+shock_epsi_carb_int_a_t)*carb_int_10_a); //Emissions costs

mc_tild_10_a_t = EM_cost_10_a_t + mc_10_a_t;              //Real marginal costs relevant for pricing (including emissions taxes)

P_10_a_t = mc_tild_10_a_t;                                       //Firm's pricing decision in abscence of nominal price rigidities

w_10_a_t  = alphaH_10_a*alphaN_10_a*mc_10_a_t*Y_10_a_t/N_10_a_t;             //FOC firm cost minimization -> labor

rk_10_a_t = alphaH_10_a*(1-alphaN_10_a)*mc_10_a_t*Y_10_a_t/K_10_a_t(-1);     //FOC firm cost minimization -> capital

PH_10_a_t = (1-alphaH_10_a)*mc_10_a_t*Y_10_a_t/H_10_a_t;  //FOC firm cost minimization -> intermediates

PH_10_a_t  = (                                                                        

@#line "Equations_10S_1C.mod" 120
+ Psi_10_1_a*P_1_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_2_a*P_2_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_3_a*P_3_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_4_a*P_4_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_5_a*P_5_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_6_a*P_6_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_7_a*P_7_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_8_a*P_8_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_9_a*P_9_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 120
+ Psi_10_10_a*P_10_a_t^(-sigh_10_a/(1-sigh_10_a))

@#line "Equations_10S_1C.mod" 122
)^(-(1-sigh_10_a)/sigh_10_a);                                             //Price index derived from opt. problem of intermediate input bundler in sector se 


@#line "Equations_10S_1C.mod" 125
H_10_1_a_t = Psi_10_1_a*(PH_10_a_t/P_1_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_2_a_t = Psi_10_2_a*(PH_10_a_t/P_2_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_3_a_t = Psi_10_3_a*(PH_10_a_t/P_3_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_4_a_t = Psi_10_4_a*(PH_10_a_t/P_4_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_5_a_t = Psi_10_5_a*(PH_10_a_t/P_5_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_6_a_t = Psi_10_6_a*(PH_10_a_t/P_6_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_7_a_t = Psi_10_7_a*(PH_10_a_t/P_7_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_8_a_t = Psi_10_8_a*(PH_10_a_t/P_8_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_9_a_t = Psi_10_9_a*(PH_10_a_t/P_9_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 125
H_10_10_a_t = Psi_10_10_a*(PH_10_a_t/P_10_a_t)^(1/(1-sigh_10_a))*H_10_a_t; //Optimal amount of sector se2 output in bundle used in sector se 

@#line "Equations_10S_1C.mod" 127

log(epsi_10_a_t/epsi_10_a_ts) = rho_eps_a*log(epsi_10_a_t(-1)/epsi_10_a_ts) + shock_epsi_10_a_t;  //Law of motion for sectoral TFP


@#line "Equations_10S_1C.mod" 131

@#line "Equations_10S_1C.mod" 132



@#line "Equations_10S_1C.mod" 135

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_2_a_t = (P_1_a_t/P_2_a_t)*(P_2_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_3_a_t = (P_1_a_t/P_3_a_t)*(P_3_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_4_a_t = (P_1_a_t/P_4_a_t)*(P_4_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_5_a_t = (P_1_a_t/P_5_a_t)*(P_5_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_6_a_t = (P_1_a_t/P_6_a_t)*(P_6_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_7_a_t = (P_1_a_t/P_7_a_t)*(P_7_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_8_a_t = (P_1_a_t/P_8_a_t)*(P_8_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_9_a_t = (P_1_a_t/P_9_a_t)*(P_9_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 136
pi_ppi_1_a_t/pi_ppi_10_a_t = (P_1_a_t/P_10_a_t)*(P_10_a_t(-1)/P_1_a_t(-1));  //(Nominal) PPI-inflation 

@#line "Equations_10S_1C.mod" 138

@#line "Equations_10S_1C.mod" 139



@#line "Equations_10S_1C.mod" 142
Y_a_t =(

@#line "Equations_10S_1C.mod" 144
+ Y_1_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_2_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_3_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_4_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_5_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_6_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_7_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_8_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_9_a_t

@#line "Equations_10S_1C.mod" 144
+ Y_10_a_t

@#line "Equations_10S_1C.mod" 146

@#line "Equations_10S_1C.mod" 147
);

end;



@#line "MS_1C_Mod_simul.mod" 76


@#line "Init_Val_MSMod_10S_1C.mod" 1
initval;

@#line "Init_Val_MSMod_10S_1C.mod" 3
C_a_t           = C_a_ts; 
I_a_t           = I_a_ts; 
N_a_t           = N_a_ts; 
K_a_t           = K_a_ts; 
w_a_t           = w_a_ts; 
rk_a_t          = rk_a_ts; 
lambda_a_t      = lambda_a_ts;
Y_a_t           = Y_a_ts;
PI_a_t          = PI_a_ts;
R_a_t           = R_a_ts;
pi_cpi_a_t      = pi_cpi_a_ts;
P_EM_a_t        = P_EM_a_ts;
epsi_a_t        = epsi_a_ts;
ZZ_a_t          = ZZ_a_ts;
Y_VA_a_t        = Y_VA_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_1_a_t     = C_1_a_ts; 
I_1_a_t     = I_1_a_ts; 
N_1_a_t     = N_1_a_ts; 
K_1_a_t     = K_1_a_ts; 
w_1_a_t     = w_1_a_ts; 
rk_1_a_t    = rk_1_a_ts;  
Y_1_a_t     = Y_1_a_ts;
epsi_1_a_t  = epsi_1_a_ts;
H_1_a_t     = H_1_a_ts;
PH_1_a_t    = PH_1_a_ts;
mc_1_a_t    = mc_1_a_ts;
P_1_a_t     = P_1_a_ts;
pi_ppi_1_a_t= pi_ppi_1_a_ts;
ZZ_1_a_t    = ZZ_1_a_ts;
Pen_1_a_t   = Pen_1_a_ts;
EM_cost_1_a_t = EM_cost_1_a_ts;
mc_tild_1_a_t = mc_tild_1_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_1_a_t = H_1_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_2_a_t = H_1_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_3_a_t = H_1_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_4_a_t = H_1_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_5_a_t = H_1_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_6_a_t = H_1_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_7_a_t = H_1_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_8_a_t = H_1_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_9_a_t = H_1_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_1_10_a_t = H_1_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_2_a_t     = C_2_a_ts; 
I_2_a_t     = I_2_a_ts; 
N_2_a_t     = N_2_a_ts; 
K_2_a_t     = K_2_a_ts; 
w_2_a_t     = w_2_a_ts; 
rk_2_a_t    = rk_2_a_ts;  
Y_2_a_t     = Y_2_a_ts;
epsi_2_a_t  = epsi_2_a_ts;
H_2_a_t     = H_2_a_ts;
PH_2_a_t    = PH_2_a_ts;
mc_2_a_t    = mc_2_a_ts;
P_2_a_t     = P_2_a_ts;
pi_ppi_2_a_t= pi_ppi_2_a_ts;
ZZ_2_a_t    = ZZ_2_a_ts;
Pen_2_a_t   = Pen_2_a_ts;
EM_cost_2_a_t = EM_cost_2_a_ts;
mc_tild_2_a_t = mc_tild_2_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_1_a_t = H_2_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_2_a_t = H_2_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_3_a_t = H_2_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_4_a_t = H_2_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_5_a_t = H_2_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_6_a_t = H_2_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_7_a_t = H_2_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_8_a_t = H_2_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_9_a_t = H_2_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_2_10_a_t = H_2_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_3_a_t     = C_3_a_ts; 
I_3_a_t     = I_3_a_ts; 
N_3_a_t     = N_3_a_ts; 
K_3_a_t     = K_3_a_ts; 
w_3_a_t     = w_3_a_ts; 
rk_3_a_t    = rk_3_a_ts;  
Y_3_a_t     = Y_3_a_ts;
epsi_3_a_t  = epsi_3_a_ts;
H_3_a_t     = H_3_a_ts;
PH_3_a_t    = PH_3_a_ts;
mc_3_a_t    = mc_3_a_ts;
P_3_a_t     = P_3_a_ts;
pi_ppi_3_a_t= pi_ppi_3_a_ts;
ZZ_3_a_t    = ZZ_3_a_ts;
Pen_3_a_t   = Pen_3_a_ts;
EM_cost_3_a_t = EM_cost_3_a_ts;
mc_tild_3_a_t = mc_tild_3_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_1_a_t = H_3_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_2_a_t = H_3_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_3_a_t = H_3_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_4_a_t = H_3_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_5_a_t = H_3_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_6_a_t = H_3_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_7_a_t = H_3_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_8_a_t = H_3_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_9_a_t = H_3_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_3_10_a_t = H_3_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_4_a_t     = C_4_a_ts; 
I_4_a_t     = I_4_a_ts; 
N_4_a_t     = N_4_a_ts; 
K_4_a_t     = K_4_a_ts; 
w_4_a_t     = w_4_a_ts; 
rk_4_a_t    = rk_4_a_ts;  
Y_4_a_t     = Y_4_a_ts;
epsi_4_a_t  = epsi_4_a_ts;
H_4_a_t     = H_4_a_ts;
PH_4_a_t    = PH_4_a_ts;
mc_4_a_t    = mc_4_a_ts;
P_4_a_t     = P_4_a_ts;
pi_ppi_4_a_t= pi_ppi_4_a_ts;
ZZ_4_a_t    = ZZ_4_a_ts;
Pen_4_a_t   = Pen_4_a_ts;
EM_cost_4_a_t = EM_cost_4_a_ts;
mc_tild_4_a_t = mc_tild_4_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_1_a_t = H_4_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_2_a_t = H_4_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_3_a_t = H_4_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_4_a_t = H_4_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_5_a_t = H_4_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_6_a_t = H_4_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_7_a_t = H_4_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_8_a_t = H_4_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_9_a_t = H_4_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_4_10_a_t = H_4_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_5_a_t     = C_5_a_ts; 
I_5_a_t     = I_5_a_ts; 
N_5_a_t     = N_5_a_ts; 
K_5_a_t     = K_5_a_ts; 
w_5_a_t     = w_5_a_ts; 
rk_5_a_t    = rk_5_a_ts;  
Y_5_a_t     = Y_5_a_ts;
epsi_5_a_t  = epsi_5_a_ts;
H_5_a_t     = H_5_a_ts;
PH_5_a_t    = PH_5_a_ts;
mc_5_a_t    = mc_5_a_ts;
P_5_a_t     = P_5_a_ts;
pi_ppi_5_a_t= pi_ppi_5_a_ts;
ZZ_5_a_t    = ZZ_5_a_ts;
Pen_5_a_t   = Pen_5_a_ts;
EM_cost_5_a_t = EM_cost_5_a_ts;
mc_tild_5_a_t = mc_tild_5_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_1_a_t = H_5_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_2_a_t = H_5_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_3_a_t = H_5_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_4_a_t = H_5_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_5_a_t = H_5_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_6_a_t = H_5_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_7_a_t = H_5_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_8_a_t = H_5_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_9_a_t = H_5_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_5_10_a_t = H_5_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_6_a_t     = C_6_a_ts; 
I_6_a_t     = I_6_a_ts; 
N_6_a_t     = N_6_a_ts; 
K_6_a_t     = K_6_a_ts; 
w_6_a_t     = w_6_a_ts; 
rk_6_a_t    = rk_6_a_ts;  
Y_6_a_t     = Y_6_a_ts;
epsi_6_a_t  = epsi_6_a_ts;
H_6_a_t     = H_6_a_ts;
PH_6_a_t    = PH_6_a_ts;
mc_6_a_t    = mc_6_a_ts;
P_6_a_t     = P_6_a_ts;
pi_ppi_6_a_t= pi_ppi_6_a_ts;
ZZ_6_a_t    = ZZ_6_a_ts;
Pen_6_a_t   = Pen_6_a_ts;
EM_cost_6_a_t = EM_cost_6_a_ts;
mc_tild_6_a_t = mc_tild_6_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_1_a_t = H_6_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_2_a_t = H_6_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_3_a_t = H_6_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_4_a_t = H_6_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_5_a_t = H_6_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_6_a_t = H_6_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_7_a_t = H_6_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_8_a_t = H_6_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_9_a_t = H_6_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_6_10_a_t = H_6_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_7_a_t     = C_7_a_ts; 
I_7_a_t     = I_7_a_ts; 
N_7_a_t     = N_7_a_ts; 
K_7_a_t     = K_7_a_ts; 
w_7_a_t     = w_7_a_ts; 
rk_7_a_t    = rk_7_a_ts;  
Y_7_a_t     = Y_7_a_ts;
epsi_7_a_t  = epsi_7_a_ts;
H_7_a_t     = H_7_a_ts;
PH_7_a_t    = PH_7_a_ts;
mc_7_a_t    = mc_7_a_ts;
P_7_a_t     = P_7_a_ts;
pi_ppi_7_a_t= pi_ppi_7_a_ts;
ZZ_7_a_t    = ZZ_7_a_ts;
Pen_7_a_t   = Pen_7_a_ts;
EM_cost_7_a_t = EM_cost_7_a_ts;
mc_tild_7_a_t = mc_tild_7_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_1_a_t = H_7_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_2_a_t = H_7_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_3_a_t = H_7_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_4_a_t = H_7_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_5_a_t = H_7_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_6_a_t = H_7_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_7_a_t = H_7_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_8_a_t = H_7_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_9_a_t = H_7_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_7_10_a_t = H_7_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_8_a_t     = C_8_a_ts; 
I_8_a_t     = I_8_a_ts; 
N_8_a_t     = N_8_a_ts; 
K_8_a_t     = K_8_a_ts; 
w_8_a_t     = w_8_a_ts; 
rk_8_a_t    = rk_8_a_ts;  
Y_8_a_t     = Y_8_a_ts;
epsi_8_a_t  = epsi_8_a_ts;
H_8_a_t     = H_8_a_ts;
PH_8_a_t    = PH_8_a_ts;
mc_8_a_t    = mc_8_a_ts;
P_8_a_t     = P_8_a_ts;
pi_ppi_8_a_t= pi_ppi_8_a_ts;
ZZ_8_a_t    = ZZ_8_a_ts;
Pen_8_a_t   = Pen_8_a_ts;
EM_cost_8_a_t = EM_cost_8_a_ts;
mc_tild_8_a_t = mc_tild_8_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_1_a_t = H_8_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_2_a_t = H_8_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_3_a_t = H_8_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_4_a_t = H_8_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_5_a_t = H_8_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_6_a_t = H_8_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_7_a_t = H_8_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_8_a_t = H_8_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_9_a_t = H_8_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_8_10_a_t = H_8_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_9_a_t     = C_9_a_ts; 
I_9_a_t     = I_9_a_ts; 
N_9_a_t     = N_9_a_ts; 
K_9_a_t     = K_9_a_ts; 
w_9_a_t     = w_9_a_ts; 
rk_9_a_t    = rk_9_a_ts;  
Y_9_a_t     = Y_9_a_ts;
epsi_9_a_t  = epsi_9_a_ts;
H_9_a_t     = H_9_a_ts;
PH_9_a_t    = PH_9_a_ts;
mc_9_a_t    = mc_9_a_ts;
P_9_a_t     = P_9_a_ts;
pi_ppi_9_a_t= pi_ppi_9_a_ts;
ZZ_9_a_t    = ZZ_9_a_ts;
Pen_9_a_t   = Pen_9_a_ts;
EM_cost_9_a_t = EM_cost_9_a_ts;
mc_tild_9_a_t = mc_tild_9_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_1_a_t = H_9_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_2_a_t = H_9_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_3_a_t = H_9_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_4_a_t = H_9_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_5_a_t = H_9_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_6_a_t = H_9_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_7_a_t = H_9_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_8_a_t = H_9_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_9_a_t = H_9_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_9_10_a_t = H_9_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 19
C_10_a_t     = C_10_a_ts; 
I_10_a_t     = I_10_a_ts; 
N_10_a_t     = N_10_a_ts; 
K_10_a_t     = K_10_a_ts; 
w_10_a_t     = w_10_a_ts; 
rk_10_a_t    = rk_10_a_ts;  
Y_10_a_t     = Y_10_a_ts;
epsi_10_a_t  = epsi_10_a_ts;
H_10_a_t     = H_10_a_ts;
PH_10_a_t    = PH_10_a_ts;
mc_10_a_t    = mc_10_a_ts;
P_10_a_t     = P_10_a_ts;
pi_ppi_10_a_t= pi_ppi_10_a_ts;
ZZ_10_a_t    = ZZ_10_a_ts;
Pen_10_a_t   = Pen_10_a_ts;
EM_cost_10_a_t = EM_cost_10_a_ts;
mc_tild_10_a_t = mc_tild_10_a_ts;

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_1_a_t = H_10_1_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_2_a_t = H_10_2_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_3_a_t = H_10_3_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_4_a_t = H_10_4_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_5_a_t = H_10_5_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_6_a_t = H_10_6_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_7_a_t = H_10_7_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_8_a_t = H_10_8_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_9_a_t = H_10_9_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 37
H_10_10_a_t = H_10_10_a_ts; 

@#line "Init_Val_MSMod_10S_1C.mod" 39

@#line "Init_Val_MSMod_10S_1C.mod" 40

@#line "Init_Val_MSMod_10S_1C.mod" 41
EM_t                = EM_ts;     
end;
@#line "MS_1C_Mod_simul.mod" 78

// ######################################################################

// Since the number of equations can become large, it may be convenient to exploit Dynare's LaTeX-writing capabilities
write_latex_dynamic_model;

//************************************************************
// 3: Run checks
//************************************************************
model_diagnostics;
resid(1);
steady;
check;

//************************************************************
// 4: Solve model (potentially declare shocks, simulation paths,...)
// Here: Simulation under perfect Foresight
//*************************************************************************


shocks;
var shock_P_EM_a_t;
periods 
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96:500
;
values 
0
0.0098834
0.0197669
0.0296504
0.0395339
0.0494174
0.04944338
0.04946936
0.04949534
0.04952132
0.0495473
0.06306842
0.07658954
0.09011066
0.10363178
0.1171529
0.12406388
0.13097486
0.13788584
0.14479682
0.1517078
0.16182176
0.17193572
0.18204968
0.19216364
0.2022776
0.21239264
0.22250768
0.23262272
0.24273776
0.2528528
0.26296556
0.27307832
0.28319108
0.29330384
0.3034166
0.31353014
0.32364368
0.33375722
0.34387076
0.3539843
0.36409814
0.37421198
0.38432582
0.39443966
0.4045535
0.41466566
0.42477782
0.43488998
0.44500214
0.4551143
0.46523012
0.47534594
0.48546176
0.49557758
0.5056934
0.51580757
0.52592174
0.53603591
0.54615008
0.55626425
0.56637842
0.57649259
0.58660676
0.59672093
0.6068351
0.61695047
0.62706584
0.63718121
0.64729658
0.65741195
0.66752732
0.67764269
0.68775806
0.69787343
0.7079888
0.71809991
0.72821102
0.73832213
0.74843324
0.75854435
0.76865546
0.77876657
0.78887768
0.79898879
0.8090999
0.81921911
0.82933832
0.83945753
0.84957674
0.85969595
0.86981516
0.87993437
0.89005358
0.90017279
0.910292; 




var shock_epsi_carb_int_a_t;
periods 
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96:500
;
values 
0
-0.027965276
-0.055930552
-0.083895828
-0.111861104
-0.13982638
-0.166727168
-0.193627955
-0.220528743
-0.247429531
-0.274330319
-0.304111022
-0.333891725
-0.363672428
-0.39345313
-0.423233833
-0.451860897
-0.48048796
-0.509115023
-0.537742087
-0.56636915
-0.591282
-0.61619485
-0.641107699
-0.666020549
-0.690933399
-0.712635956
-0.734338512
-0.756041069
-0.777743626
-0.799446183
-0.81426112
-0.829076057
-0.843890995
-0.858705932
-0.873520869
-0.883349557
-0.893178244
-0.903006932
-0.912835619
-0.922664307
-0.92920585
-0.935747394
-0.942288938
-0.948830481
-0.955372025
-0.959367683
-0.963363341
-0.967358999
-0.971354657
-0.975350314
-0.978194234
-0.981038154
-0.983882074
-0.986725994
-0.989569914
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99
-0.99;

end;


options_.simul.maxit=20;
simul(periods=600,stack_solve_algo=0);


